Attribute VB_Name = "Utility"
Option Explicit
'#########################################################################
' Subroutine Name: enrollmentDateCreate
'
' Description: This sub-routine creates an enrollment data record for
' the given provider pin. The record is created with all the data fields
' set to zero. An extension to this subroutine would have extra arguments
' for the age group data.
'
' Arguments: aPIN - The provider pin
'            aChangeDate - The date that the record was changed (inserted)
'            aUserID - The name of the user who inserted the data
'            aConnection
'
' Exceptions: None
'
' CHANGE HISTORY
' Request Id  Date        Author          Description
' ------------------------------------------------------------------------
' R1352       11/05/2001  Stephen Nelson  ODBC 6.0 does not work with the
'                                         DateValue() function.  Replaced
'                                         with brackets {}.
' R1812:D4358       09/22/2004  Stephen Nelson  Added fields other1 - other4.
'#########################################################################
Public Sub enrollmentDataUpdate(aPIN As String, aChangeDate As Date, aUserID As String, aConnection As ADODB.Connection)
On Error GoTo ErrorHandler
    Dim query As String
    
    If ValidateEnrollmentRecord(aPIN, aConnection) = False Then
        ' create an enrollment record with zero values
        query = "INSERT INTO enroll "
        query = query & "(pin, chgdate, userid,"
        query = query & "allkids1, medicaid1, uninsured1, amindian1, fqhc_rhc1, vfckids1, g317kids1, statekids1,"
        query = query & "allkids2, medicaid2, uninsured2, amindian2, fqhc_rhc2, vfckids2, g317kids2, statekids2,"
        query = query & "allkids3, medicaid3, uninsured3, amindian3, fqhc_rhc3, vfckids3, g317kids3, statekids3,"
        query = query & "allkids4, medicaid4, uninsured4, amindian4, fqhc_rhc4, vfckids4, g317kids4, statekids4,"
        query = query & "other1, other2, other3, other4)"  ' R1812:D4358 Change
        query = query & "VALUES "
        query = query & "('" & aPIN & " ',{" & aChangeDate & " },'" & aUserID & "',"  ' R1272 Change
        query = query & 0 & "," & 0 & "," & 0 & "," & 0 & "," & 0 & "," & 0 & "," & 0 & "," & 0 & ","
        query = query & 0 & "," & 0 & "," & 0 & "," & 0 & "," & 0 & "," & 0 & "," & 0 & "," & 0 & ","
        query = query & 0 & "," & 0 & "," & 0 & "," & 0 & "," & 0 & "," & 0 & "," & 0 & "," & 0 & ","
        query = query & 0 & "," & 0 & "," & 0 & "," & 0 & "," & 0 & "," & 0 & "," & 0 & "," & 0 & ","
        query = query & 0 & "," & 0 & "," & 0 & "," & 0 & ")"   ' R1812:D4358 Change
        
        aConnection.Execute query
        
    End If

Exit Sub

ErrorHandler:
    Err.Raise Err
    
End Sub
'#########################################################################
' Function Name: getVialSize
'
' Description: Returns the vial size of the given vaccine, lot number combo
'
' Arguments: aVaccine
'            aLotNumber
'            aConnection
'
' Returns : vialSize
' Exceptions: None
'
'#########################################################################
Public Function getVialSize(aVaccine As String, aLotNumber As String, aConnection As ADODB.Connection) As Long
On Error GoTo ErrorHandler
    Dim recordset As ADODB.recordset
    Dim query As String
    Dim rowCount As Long
    Dim vialSize As Long
    Dim doseSize As Long
    Dim mutilple As Integer
    Dim lotNumber As String
    
    lotNumber = Replace(aLotNumber, "-", "")
    
    Set recordset = CreateObject("ADODB.Recordset")
    
    query = "SELECT size FROM Lots "
    query = query & "WHERE ltrim(rtrim(vaccine)) = '" & aVaccine & "' "
    query = query & "AND ltrim(rtrim(strtran(lot,ltrim(rtrim('-')),''))) = '" & lotNumber & "' "
    
    recordset.Open query, aConnection, adOpenKeyset, adLockReadOnly, adCmdText
    rowCount = recordset.recordCount
    
    If (rowCount <> 1) And (rowCount <> 0) Then
         RaiseError VM_AVAIL_INVENTORY_LOT_COUNT_ERROR_NUMBER, _
                    VM_AVAIL_INVENTORY_LOT_COUNT_ERROR_MESSAGE
    End If
    
    If rowCount = 0 Then
        vialSize = 1
    End If
    
    If rowCount = 1 Then
        If IsNull(recordset.Fields.Item(0)) = False Then
            vialSize = recordset.Fields.Item(0)
        Else
            vialSize = 1
        End If
    End If
    
    getVialSize = vialSize
    
    CloseRecordSet recordset
    Set recordset = Nothing
    
Exit Function

ErrorHandler:

    With recordset
        If .state = adStateOpen Then
            .Close
        End If
    End With
    
    Set recordset = Nothing
    
    Err.Raise Err
    
End Function
'#########################################################################
' Function Name: IsAlphaNumeric
'
' Description: Checks if the given string is alphanumeric.
'
' Arguments: aString
'
' Returns : True if aString is alphanumeric and false otherwise.
' Exceptions: None
'#########################################################################
Public Function IsAlphaNumeric(aString As String) As Boolean
On Error GoTo ErrorHandler
    Dim RetVal As Boolean
    Dim stringLength As Long
    Dim index As Long
    Dim charCode As Integer
    
    stringLength = Len(Trim(aString))
    
    If stringLength = 0 Then
        RetVal = False
    Else
        RetVal = True
    End If
    
    For index = 1 To stringLength
        charCode = Asc(mid(aString, index, 1))
        If Not ((CHAR_0 <= charCode And charCode <= CHAR_9) Or (CHAR_A <= charCode And charCode <= CHAR_Z) Or (CHAR_Aa <= charCode And charCode <= CHAR_Zz)) Then
            RetVal = False
            Exit For
        End If

    Next index
    
    IsAlphaNumeric = RetVal
Exit Function

ErrorHandler:
    Err.Raise Err
    
End Function

'#########################################################################
' Subroutine Name: CloseRecordSet
'
' Description: Utility function to close and destroy a recordset. The
' function checks whether the recordset is open before attempting to close it.
' It the recordset is not open, then the function just sets it to nothing
'
' Arguments: aRecordSet
'
' Exceptions: None
'#########################################################################
Public Sub CloseRecordSet(aRecordSet As ADODB.recordset)

On Error GoTo ErrorHandler
    With aRecordSet
        If .state = adStateOpen Then
            .Close
        End If
    End With
    
Exit Sub
    
ErrorHandler:
        Err.Raise Err
End Sub
'#########################################################################
' Subroutine Name: RaiseError
'
' Description: Subroutine raises an Err object with the given error number
' and error message. It uses the App objects EXEName property as the
' source of the error. Currently there are no help files so these
' help-related properties of the Err object are not set
'
' Arguments: anErrorNumber, anErrorMessage
'
' Exceptions: The specified exception
'#########################################################################
Public Sub RaiseError(anErrorNumber As Long, anErrorMessage As String)
    
On Error GoTo ErrorHandler:
        
    Dim appName As String
    appName = App.EXEName
        
    Err.Raise vbObjectError + anErrorNumber, _
            appName, _
            anErrorMessage
    
Exit Sub
    
ErrorHandler:
    Debug.Print Err.source
    Debug.Print Err.Description
    Debug.Print Err.Number
    Debug.Print Err.HelpFile
    Debug.Print Err.HelpContext
    Err.Raise Err
    
End Sub


'#########################################################################
' Function Name: ValidateNullString
'
' Description: Utility function that checks if the input string
' is a null string or a zero-length string.
'
' Arguments: aString
'
' Returns: True if the input string is a null string or a  zero-length
' string and False otherwise
'
' Exceptions: None
'#########################################################################

Public Function ValidateNullString(aString As String) As Boolean
On Error GoTo ErrorHandler
Dim aNullFlag As Boolean
Dim myStringLength As Integer

aNullFlag = IsNull(aString)
myStringLength = Len(Trim(aString))
    If aNullFlag Or (myStringLength = 0) Then
        ValidateNullString = True
    Else
        ValidateNullString = False
    End If
        
    Exit Function
    
ErrorHandler:
    Err.Raise Err
    
End Function

'#########################################################################
' Function Name: addStringToWhereClause
'
' Description: Adds a where clause involving a string to the where clause
'              of a SQL query, or, if the where clause passed in is Null,
'              it starts the where clause.  The function returns the entire
'              new where clause
' Arguments:   A string value, a pre-existing or empty SQL where clause,
'              and the column name to which the value should be compared
'
' Exceptions: None
'#########################################################################

Public Function addStringToWhereClause(aString As String, aWhereClause As String, aColumnName As String) As String
On Error GoTo ErrorHandler

   If ValidateNullString(aString) = False Then
      If ValidateNullString(aWhereClause) = True Then
         aWhereClause = " WHERE "
      Else
         aWhereClause = aWhereClause & " AND "
      End If
   
      addStringToWhereClause = aWhereClause & "ltrim(rtrim(" & aColumnName & ")) = '" & _
                                 aString & "'"
                                 
   Else
      addStringToWhereClause = aWhereClause
   End If
   
   Exit Function
ErrorHandler:
   Err.Raise Err
End Function

'#########################################################################
' Function Name: convertRecordSetToResultSet
'
' Description: Takes an ado RecordSet as an argument, and loops through
'              the fields name inserting them into a header collection,
'              then loops through the value fields inserting them into a
'              data collection.  These two collections are then inserted
'              into a cRecordSet object.
'
' Arguments:
'
'
' Exceptions: None
'
' CHANGE HISTORY
' Request Id  Date        Author          Description
' ------------------------------------------------------------------------
' R1352       11/05/2001  Stephen Nelson  ODBC 6.0 does not remove the trailing
'                                         spaces from a value returned from
'                                         a query. Clean up the data so the
'                                         application does not need to worry
'                                         about extra spaces.
'#########################################################################
Public Function convertRecordSetToResultSet(aRecordSet As ADODB.recordset) As cResultSet

On Error GoTo ErrorHandler
Dim recordCount As Long
Dim fieldCounter As Long
Dim rowCounter As Long
Dim singleRow As New Collection
Dim headersCollection As New Collection
Dim dataCollection As New Collection
Dim results As cResultSet
Dim collectionIndex As String

   Set results = CreateObject("VACMAN.cResultSet")
   
   'Set recordCount to the number of records in the recordset
   
   recordCount = aRecordSet.Fields.Count - 1

   'Put header into cResultSet object header collection
   'Loop through first row of the recordset, and put the name of each item into the
   'cResultSet headerscollection
   'The key field is one greater than the fieldCounter because the fieldCounter is 0
   'indexed and the key should be 1-indexed
   
   For fieldCounter = 0 To recordCount
      headersCollection.Add Item:=aRecordSet.Fields(fieldCounter).Name, Key:=CStr(fieldCounter + 1)
   Next fieldCounter
    
   'Initialize rowCounter to track number of records
   
   rowCounter = 0
    
   'Loop through each row, putting the results into a collection
   'Then add each collection (each singlerow) into the overall dataCollection,
   'a collectoon of collections
   
   While Not aRecordSet.EOF
      Set singleRow = Nothing
      For fieldCounter = 0 To recordCount
         collectionIndex = CStr(fieldCounter + 1)
      
         If aRecordSet.Fields(fieldCounter).Type = adDBDate Then
            singleRow.Add Item:=Format(aRecordSet.Fields(fieldCounter).Value, "mm/dd/yyyy"), Key:=collectionIndex
         ''' R1272 Start Changes
         ElseIf Trim(aRecordSet.Fields(fieldCounter).Value) = vbNullString Then
            singleRow.Add Item:=" ", Key:=collectionIndex
         Else
            ''' R1272 singleRow.Add Item:=aRecordSet.Fields(fieldCounter).Value, Key:=collectionIndex
            singleRow.Add Item:=Trim(aRecordSet.Fields(fieldCounter).Value), Key:=collectionIndex
         End If
         ''' R1272 End Changes
      Next fieldCounter
      rowCounter = rowCounter + 1
      dataCollection.Add Item:=singleRow, Key:=CStr(rowCounter)
      aRecordSet.MoveNext
   Wend
   
   'Create a cResultSet and read in the data and headers
   
   Set results.Data = dataCollection
   Set results.Headers = headersCollection
   results.Rows = dataCollection.Count
   results.Cols = recordCount + 1
   Set convertRecordSetToResultSet = results
   
   'Clean up objects
   
   Set dataCollection = Nothing
   Set headersCollection = Nothing
   Set singleRow = Nothing
   Set results = Nothing
    
   Exit Function

    
ErrorHandler:
            Set dataCollection = Nothing
            Set headersCollection = Nothing
            Set singleRow = Nothing
            Set results = Nothing
            Err.Raise Err
                   
End Function

'#########################################################################
' Function Name: ManufacturerOrderDoses
'
' Description: This function returns the total number of doses
' in a manufacturer order that is defined by the input parameters
'
' Arguments:
'
' Returns:
'
' Exceptions:
'
' CHANGE HISTORY
' Request Id  Date        Author          Description
' ------------------------------------------------------------------------
' R1352       11/05/2001  Stephen Nelson  ODBC 6.0 does not work with the
'                                         DateValue() function.  Replaced
'                                         with brackets {}.
' R1596       03/04/2002  Joe Bernard     ODBC 6.0 also does not work with
'                                         ltrim and rtrim on numeric or
'                                         date values. Removed these on
'                                         orddate field.
' R1812:D4358       09/30/2004  Stephen Nelson  Manufacturer direct orders are
'                                         now processed through the NEWORDER
'                                         table, and not the STOCK table.
'                                         Made the necessary changes in
'                                         this procedure.
'                                         This change occurred with
'                                         the release of Vacman 3.0.8.
'                                         Also, cleaned up the old code
'                                         that had been commented out from
'                                         past releases.
'#########################################################################
Public Function ManufacturerOrderDoses(anOrderDate, aPIN, aVaccine, aFundingSource, Connection) As Long
On Error GoTo ErrorHandler
    Dim recordset As ADODB.recordset
    Dim query As String
    Dim doses As Long
    Dim rowCount As Long
    
    
    Set recordset = CreateObject("ADODB.RecordSet")
    
    query = "SELECT orddose "
    query = query & "FROM neworder "   ' R1812:D4358 Change
    query = query & "WHERE ltrim(rtrim(pin)) = '" & aPIN & "' "
    query = query & "AND ltrim(rtrim(vaccine)) = '" & aVaccine & "' "
    query = query & "AND orddate = {" & anOrderDate & "} "
    query = query & "AND ltrim(rtrim(fcode1)) = '" & aFundingSource & "'"
    
    recordset.Open query, Connection, adOpenKeyset, adLockReadOnly, adCmdText
    rowCount = recordset.recordCount
    
    If rowCount <> 1 Then
        RaiseError VM_DOSES_ERROR_NUMBER, _
            VM_DOSES_ERROR_MESSAGE
    Else
        If IsNull(recordset.Fields.Item(0)) = False Then
            ManufacturerOrderDoses = recordset.Fields.Item(0)
        Else
            ManufacturerOrderDoses = 0
        End If
    End If
        
    CloseRecordSet recordset
    Set recordset = Nothing
    
Exit Function
    
ErrorHandler:
    CloseRecordSet recordset
    Set recordset = Nothing
    
    Err.Raise Err
End Function
'#########################################################################
' Function Name: AdjustmentCode
'
' Description: Function returns an adjustment code for the given
' adjustment string. An exception is thrown if the adjustment string
' is not found in the database or if duplicate adjustment strings are found
'
' Arguments: aTransactionCode
'            aConnection
'
' Returns: Returns the adjustment code associated with the given adjustment string
'
' Exceptions: VM_ACTION_CODE_ERROR, VM_DUPLICATE_ACTION
'#########################################################################
Public Function AdjustmentCode(anAdjustmentString As String, aConnection As ADODB.Connection) As Long
On Error GoTo ErrorHandler
    
    Dim query As String
    Dim recordset As ADODB.recordset
    Dim rowCount As Long
    
    Set recordset = CreateObject("ADODB.RecordSet")
    
    query = "SELECT action "
    query = query & "FROM actref "
    query = query & "WHERE status = '" & anAdjustmentString & "'"
        
    recordset.Open query, aConnection, adOpenKeyset, adLockReadOnly, adCmdText
    rowCount = recordset.recordCount
        
    If rowCount < 1 Then
        RaiseError VM_ACTION_CODE_ERROR_NUMBER, _
                VM_ACTION_CODE_ERROR_MESSAGE
    ElseIf rowCount > 1 Then
        RaiseError VM_DUPLICATE_ACTION_CODES_NUMBER, _
                VM_DUPLICATE_ACTION_CODES_MESSAGE
    Else
        If IsNull(recordset.Fields.Item(0)) = False Then
            AdjustmentCode = recordset.Fields.Item(0)
        Else
            AdjustmentCode = 0
        End If
    End If

    recordset.Close
    Set recordset = Nothing
    
Exit Function

ErrorHandler:
    CloseRecordSet recordset
    Err.Raise Err

End Function
    
'#########################################################################
' Function Name: TransactionDoses
'
' Description: The function returns the number of doses in the
' transaction defined by the input parameters. The input parameters
' define a unique record in the database
'
' Arguments: aTransactionCode, aConnection
'
' Returns: The number of doses in the transaction defined by the input
' parameters.
'
' Exceptions: VM_DOSES_ERROR_NUMBER
'
' CHANGE HISTORY
' Request Id  Date        Author          Description
' ------------------------------------------------------------------------
' R1352       11/05/2001  Stephen Nelson  ODBC 6.0 does not work with the
'                                         DateValue() function.  Replaced
'                                         with brackets {}.
' R1596       03/04/2002  Joe Bernard     ODBC 6.0 also does not work with
'                                         ltrim and rtrim on numeric or
'                                         date values. Removed these on
'                                         action and aTransactionDate field.
'#########################################################################
Public Function TransactionDoses(aTransactionCode As Long, aPIN As String, aVaccine As String, aLotNumber As String, aTransactionDate As String, fromPIN As String, aConnection As ADODB.Connection) As Long

On Error GoTo ErrorHandler
    Dim query As String
    Dim recordset As ADODB.recordset
    Dim rowCount As Long
    Dim lotNumber As String
    
    lotNumber = Replace(aLotNumber, "-", "")
    
    Set recordset = CreateObject("ADODB.RecordSet")
    
    query = "SELECT doses "
    query = query & "FROM distrib "
    'R1596 query = query & "WHERE ltrim(rtrim(action)) = " & aTransactionCode & " "
    query = query & "WHERE action = " & aTransactionCode & " "  'R1596 - Changed from above
    query = query & "AND ltrim(rtrim(pin)) = '" & aPIN & "' "
    query = query & "AND ltrim(rtrim(vaccine)) = '" & aVaccine & "' "
    query = query & "AND ltrim(rtrim(strtran(lot,ltrim(rtrim('-')),''))) = '" & lotNumber & "' "
    ''' R1272 query = query & "AND ltrim(rtrim(dateout)) = DateValue('" & aTransactionDate & "') "
    'R1596 query = query & "AND ltrim(rtrim(dateout)) = {" & aTransactionDate & "} "
    query = query & "AND dateout = {" & aTransactionDate & "} "  'R1596 - Changed from above
    query = query & "AND ltrim(rtrim(frompin)) = '" & fromPIN & "'"

    recordset.Open query, aConnection, adOpenKeyset, adLockReadOnly, adCmdText
    rowCount = recordset.recordCount
    
    If rowCount <> 1 Then
        RaiseError VM_DOSES_ERROR_NUMBER, _
            VM_DOSES_ERROR_MESSAGE
    Else
        If IsNull(recordset.Fields.Item(0)) = False Then
        TransactionDoses = recordset.Fields.Item(0)
        Else
        TransactionDoses = 0
        End If
    End If
        
    CloseRecordSet recordset
    Set recordset = Nothing
    
Exit Function

ErrorHandler:
    CloseRecordSet recordset
    Set recordset = Nothing
    
    Err.Raise Err
    
 End Function
 
'#########################################################################
' Function Name: stripString
'
' Description:
'
' Arguments:
'
' Returns: Returns the input string but without slashes, dashes, spaces, and parens
'
' Exceptions:
'#########################################################################

Public Function stripString(inString As String) As String
    Dim RetVal As String
        RetVal = stripParens(stripDashes(stripSlashes(stripSpaces(inString))))
    stripString = RetVal
End Function
'#########################################################################
' Function Name: stripDashes
'
' Description:
'
' Arguments:
'
' Returns: This function removes all dashes from the strip and returns it
'
' Exceptions:
'#########################################################################
Public Function stripDashes(inString As String) As String
Dim tmpString As String
Dim index As Long
Dim found As Boolean

tmpString = inString
found = True

While True = found
    index = InStr(tmpString, "-")
    If index = 0 Then
        found = False
    Else
        If index > 1 Then
            tmpString = Left(tmpString, index - 1) + Right(tmpString, Len(tmpString) - index)
        Else
            tmpString = Right(tmpString, Len(tmpString) - 1)
        End If
    End If
Wend

stripDashes = tmpString

End Function

'#########################################################################
' Function Name: stripSlashes
'
' Description:
'
' Arguments:
'
' Returns: This function strips all the slahes from a string
'
' Exceptions:
'#########################################################################

Public Function stripSlashes(inString As String) As String
Dim tmpString As String
Dim index As Long
Dim found As Boolean

tmpString = inString
found = True

While True = found
    index = InStr(tmpString, "/")
    If index = 0 Then
        found = False
    Else
        If index > 1 Then
            tmpString = Left(tmpString, index - 1) + Right(tmpString, Len(tmpString) - index)
        Else
            tmpString = Right(tmpString, Len(tmpString) - 1)
        End If
    End If
Wend

stripSlashes = tmpString

End Function

'#########################################################################
' Function Name: stripTabs
'
' Description:
'
' Arguments:
'
' Returns: This function strips all the tabs from a string
' not very useful right now
'
' Exceptions:
'#########################################################################

Public Function stripTabs(inString As String) As String
Dim tmpString As String
Dim index As Long
Dim found As Boolean

tmpString = inString
found = True

While True = found
    index = InStr(tmpString, vbTab)
    If index = 0 Then
        found = False
    Else
        If index > 1 Then
            tmpString = Left(tmpString, index - 1) + Right(tmpString, Len(tmpString) - index)
        Else
            tmpString = Right(tmpString, Len(tmpString) - 1)
        End If
    End If
Wend

stripTabs = tmpString

End Function

'#########################################################################
' Function Name: stripSpaces
'
' Description:
'
' Arguments:
'
' Returns:  Removes spaces from a string
'
' Exceptions:
'#########################################################################

Public Function stripSpaces(inString As String) As String
Dim tmpString As String
Dim index As Long
Dim found As Boolean

tmpString = inString
found = True

While True = found
    index = InStr(tmpString, " ")
    If index = 0 Then
        found = False
    Else
        If index > 1 Then
            tmpString = Left(tmpString, index - 1) + Right(tmpString, Len(tmpString) - index)
        Else
            tmpString = Right(tmpString, Len(tmpString) - 1)
        End If
    End If
Wend

stripSpaces = tmpString

End Function

'#########################################################################
' Function Name: stripParens
'
' Description:
'
' Arguments:
'
' Returns:  Removes parens from a string , parens = ()
'
' Exceptions:
'#########################################################################
Public Function stripParens(inString As String) As String
Dim tmpString As String
Dim index As Long
Dim found As Boolean

tmpString = inString
found = True

While True = found
    index = InStr(tmpString, "(")
    If index = 0 Then
        found = False
    Else
        If index > 1 Then
            tmpString = Left(tmpString, index - 1) + Right(tmpString, Len(tmpString) - index)
        Else
            tmpString = Right(tmpString, Len(tmpString) - 1)
        End If
    End If
Wend

found = True

While True = found
    index = InStr(tmpString, ")")
    If index = 0 Then
        found = False
    Else
        If index > 1 Then
            tmpString = Left(tmpString, index - 1) + Right(tmpString, Len(tmpString) - index)
        Else
            tmpString = Right(tmpString, Len(tmpString) - 1)
        End If
    End If
Wend

stripParens = tmpString

End Function

'#########################################################################
' Function Name: stripInvalidCharacters
'
' Description:
'
' Arguments: ByVal aString As String
'
' Returns:  Removes specific invalid chars (!@#$%^&*()+|\/{}[]:<>?"')
'           from a string
'
' Exceptions:
'#########################################################################
Public Function stripInvalidCharacters(ByVal aString As String) As String

On Error GoTo ErrorHandler

    Dim RetVal As String
    RetVal = vbNullString
    
    Dim Length As Integer
    Length = Len(aString)
    
    Dim i As Integer
    For i = 1 To Length
    
        Dim c As String
        c = mid(aString, i, 1)
                
        'Filter out invalid characters...only add valid characters to RetVal
        If InStr(1, "!@#$%^&*()+|\/{}[]:<>?""'", c, vbTextCompare) = 0 Then
            
            RetVal = RetVal + c
            
        End If
                
    Next i

    stripInvalidCharacters = RetVal

    Exit Function
    
ErrorHandler:

    stripInvalidCharacters = vbNullString
    
    Err.Raise Err

End Function
