VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "cResultSet"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True
'#########################################################################
' Copyright  Center for Disease Control and Prevention, 1998.
'
' File Name: cResultSet
'
' Description:  This class encapsulates the data from an ado Recordset
'

' Original Author: Anand Ramakrishnan
'
' Date Created: 02/16/98
' $Archive: $
' $Revision: 1.3 $
' $Date: 1999/01/20 21:35:37 $
' $Author: immpact $
'#########################################################################


Option Explicit

Private Const INVALID_ROW_ERROR As Long = 50000
Private Const INVALID_COL_ERROR As Long = 50001

Private Const INVALID_ROW_MESSAGE As String = "Invalid Row Specified"
Private Const INVALID_COL_MESSAGE As String = "Invalid Col Specified"

Private Const ERROR_SOURCE As String = "cResultSet"

Private myCols As Long
Private myRows As Long

Private myData As Collection
Private myHeaders As Collection





Private Sub Class_Initialize()

    myCols = 0
    myRows = 0
    
    Set myData = Nothing
    Set myHeaders = Nothing

End Sub

Private Sub Class_Terminate()

    myCols = 0
    myRows = 0
    
    Set myData = Nothing
    Set myHeaders = Nothing
    
End Sub



Public Property Get Cols() As Long

    Cols = myCols

End Property

Public Property Let Cols(ByVal aCols As Long)

    myCols = aCols
    
End Property

Public Property Get Rows() As Long

    Rows = myRows

End Property

Public Property Let Rows(ByVal aRows As Long)

    myRows = aRows

End Property

Public Property Get Data() As Collection

    Set Data = myData

End Property

Public Property Set Data(ByVal aData As Collection)

    Set myData = aData

End Property

Public Property Get Headers() As Collection

    Set Headers = myHeaders

End Property

Public Property Set Headers(ByVal aHeaders As Collection)

    Set myHeaders = aHeaders

End Property

'#########################################################################
' Function Name: Clear
'
' Description: Clears all of the data members in cResultSet
'
' Arguments: NONE
'
' Returns: Nothing
'
' Exceptions:
'#########################################################################
Public Sub CLEAR()

    Cols = 0
    Rows = 0
    Set Data = Nothing
    Set Headers = Nothing

End Sub

'#########################################################################
' Function Name: SetValue
'
' Description:
'
' Arguments: NONE
'
' Returns: Nothing
'
' Exceptions:
'#########################################################################
Public Sub SetValue(aRow As Long, aCol As Long, aValue As String)

    Dim acolCollection As Collection
    
    With Data
    
        If aRow > .Count Then
            
           RaiseError INVALID_ROW_ERROR, INVALID_ROW_MESSAGE
            
        Else
                                                    
            Set acolCollection = Data(CStr(aRow))
                                                    
            If aCol <= acolCollection.Count Then
                
                acolCollection.Remove CStr(aCol)
                                
            End If
                    
            acolCollection.Add Item:=aValue, Key:=CStr(aCol)
            
            .Remove CStr(aRow)
            .Add Item:=acolCollection, Key:=CStr(aRow)
                        
        End If
    
    End With
    
    Set acolCollection = Nothing

End Sub

'#########################################################################
' Function Name: GetValue
'
' Description:
'
' Arguments: NONE
'
' Returns: String
'
' Exceptions: INVALID_ROW_ERROR, INVALID_COL_ERROR
'#########################################################################
Public Function GetValue(aRow As Long, aCol As Long) As String

    Dim acolCollection As Collection
    
    With Data
    
        If aRow > .Count Then
            
            RaiseError INVALID_ROW_ERROR, INVALID_ROW_MESSAGE
            
        Else
                                                    
            Set acolCollection = Data(CStr(aRow))
            
            If aCol > acolCollection.Count Then
                
                RaiseError INVALID_COL_ERROR, INVALID_COL_MESSAGE
                
            End If
            
            If IsNull(acolCollection(CStr(aCol))) = True Then
               GetValue = vbNullString
            Else
               GetValue = acolCollection(CStr(aCol))
            End If
            
        End If
    
    End With
    
    Set acolCollection = Nothing

End Function

'#########################################################################
' Function Name: AddRow
'
' Description:
'
' Arguments: NONE
'
' Returns: Nothing
'
' Exceptions:
'#########################################################################
Public Sub AddRow(Optional aCollection As Variant)

    'Increment the total number of rows by 1
    Rows = Rows + 1
    
    Dim NextRow As Long
    NextRow = Data.Count + 1

    If IsMissing(aCollection) = True Then
    
        Dim colCollection As New Collection
            
        Data.Add Item:=colCollection, Key:=CStr(NextRow)
        
        Set colCollection = Nothing
        
        Dim ColCount As Long
        ColCount = Cols
        
        Dim Col As Long
        For Col = 1 To ColCount
        
            SetValue NextRow, Col, vbNullString
        
        Next Col
        
    Else
    
        Data.Add Item:=aCollection, Key:=CStr(NextRow)
    
    End If

End Sub

'#########################################################################
' Function Name: DeleteRow
'
' Description:
'
' Arguments: aRow - the row to be deleted
'
' Returns: Nothing
'
' Exceptions:
'#########################################################################
Public Sub DeleteRow(aRow As Long)

    'Decrement the total number of rows by 1
    Rows = Rows - 1
    
    Dim NewDataCollection As New Collection

    With Data
            
        Dim ItemCount As Long
        ItemCount = .Count
                
        Dim NewItem As Long
        NewItem = 1
        
        Dim Item As Long
        For Item = 1 To ItemCount
                    
            If Item <> aRow Then
                                        
                NewDataCollection.Add Item:=.Item(Item), Key:=CStr(NewItem)
                NewItem = NewItem + 1
                
            End If
                            
        Next Item
    
    End With
    
    Set Data = Nothing
    Set Data = NewDataCollection
    
    Set NewDataCollection = Nothing
    
End Sub



