VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "cVacMan"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True
Option Explicit
'#########################################################################
' Copyright  Center for Disease Control and Prevention, 1998.
'
' File Name: VacManFunctions.cls
'
' Description: Contains all VACMAN database functions.  This includes four read
'              functions (stockTableRead, manufacturerProviderOrderRead,
'              inventoryOnHandRead and vaccineReferenceTableRead),  *KLUGE*
'              other functions should be listed here
'              This class contains openConnection and closeConnection sub-
'              routines which need to be called externally to handle the
'              connection to the database through which the other functions
'               are called.
' Original Author: Rachel Schiff
'
' CHANGE HISTORY
' Request ID   Date        Author          Description
' ------------------------------------------------------------------------
' R1812        09/21/2004  Stephen Nelson  Release Tulane
'                                          Modified code to work with
'                                          version 3.0 of the Vacman database
'
' Date Created:  April 27, 1998
' $Archive: $
' $Revision: 1.36 $
' $Date: 2004/11/19 13:57:47 $
' $Author: ldoucett $
'#########################################################################
'One connection for the entire class
Private myConnection As ADODB.Connection
Private myConnectionString As String

' R1812 Start Change
' New Type to capture and return values
' associated with the pvaccref table.
Type Contract
    vaccine As String
    maker As String
    begin As Date
    end As Date
    minbulk As Long
    unitsize As Long
    pkgsize As Long
    ndcno As String
    cost As Double
    contractid As String
    sel_maker As String
    dos_wind As String
    excfunds As String
    descrip As String
End Type
' R1812 End Changes

'#########################################################################
' Subroutine Name: Class_Initialize
'
' Description:  Creates connection object, but does not open it.
'               This subroutine is called whenever the first call to the
'              VacMan object is made.
'
' Arguments:   None
'
' Exceptions:  None
'#########################################################################
Private Sub Class_Initialize()

On Error GoTo ErrorHandler
    App.StartLogging VACMAN_LOG_PATH, 0
   Set myConnection = CreateObject("ADODB.Connection")
Exit Sub

ErrorHandler:
    Err.Raise Err
    
End Sub


'#########################################################################
' Property Name: Get Connection
'
' Description:  The Get Connection property first checks to see whether the
'              class-level connection object is open to the database.
'              If so, it returns the connection object.  If not, it opens
'              the connection using the connection string stored by the
'              openConnection method.  For maximum flexibility, the
'              connection will be opened in Read/Write mode.
'
' Arguments:   Database connection string
'
' Exceptions:  None
'#########################################################################
Public Property Get Connection() As ADODB.Connection
On Error GoTo ErrorHandler
    App.LogEvent "Begin: Get Connection()", vbLogEventTypeInformation
    'With myConnection
    '  If .State = adStateOpen Then
    '     .Close
    '  End If
    'End With

    If Not (myConnection.state = adStateOpen) Then
        With myConnection
            .ConnectionString = myConnectionString
            .Mode = adModeReadWrite
            .Open
        End With
    End If
       
    Set Connection = myConnection
    App.LogEvent "End: GetConnection()", vbLogEventTypeInformation
    Exit Property

ErrorHandler:
    Dim desc As String
    Dim code As Long
    desc = Err.Description
    code = Err.Number
    
    App.LogEvent "Problem: In GetConnection() " & desc, vbLogEventTypeError
    
    Err.Raise code, "VACMAN DLL", desc
    
End Property
'#########################################################################
' Subroutine Name: openConnection
'
' Description:  The openConnection Method does not actually open a
'               connection.  Instead it takes the connection string argument
'              that is passed in to it, which must be a valid ado connection
'              string, and stores that in the class-level
'              myConnectionString variable.  The actual opening of a database
'              connection is done in the Get Connection property.  Whenever the
'              property is used, the class level connection is opened using the
'              connection string if the connection was not already open.
'
'
' Arguments:   Database connection string
'
' Exceptions:  None
'#########################################################################
Public Sub openConnection(ByVal aConnectionString As String)

'Open the connection, using the connection string passed in
On Error GoTo ErrorHandler
   App.LogEvent "Begin: openConnection()", vbLogEventTypeInformation
   myConnectionString = aConnectionString
   App.LogEvent "Begin: openConnection()", vbLogEventTypeInformation
   Exit Sub
   
ErrorHandler:

   Dim desc As String
    Dim code As Long
    desc = Err.Description
    code = Err.Number
    
    App.LogEvent "Problem: In openConnection() " & desc, vbLogEventTypeError
    
    Err.Raise code, "VACMAN DLL", desc


End Sub
'#########################################################################
' Subroutine Name: CloseConnection
'
' Description: Utility function to close a connection to the database. The
' function checks whether the connection is open before attempting to close it.
'
'
' Arguments: aRecordSet
'
' Exceptions: None
'#########################################################################
Public Sub closeConnection()
   'After all calls are made, close connection
On Error GoTo ErrorHandler
   App.LogEvent "Begin: closeConnection()", vbLogEventTypeInformation
   With myConnection
      If .state = adStateOpen Then
         .Close
      End If
   End With
    App.LogEvent "End: closeConnection()", vbLogEventTypeInformation
   
Exit Sub

ErrorHandler:
    Dim desc As String
    Dim code As Long
    desc = Err.Description
    code = Err.Number
    
    App.LogEvent "Problem: In closeConnection() " & desc, vbLogEventTypeError
    
    Err.Raise code, "VACMAN DLL", desc
    
End Sub

'#########################################################################
' Subroutine Name: getContractDetails
'
' Description: Queries the pvaccref table to identify details of the
'              contract in force on a given date.
'
'
' Arguments:   aShipmentDate - Each contract has a begin and end date. The
'                              shipment date is compared to the begin and end
'                              date when attempting to determine the contract
'                              that needs to be returned to the calling
'                              procedure.
'              aVaccine - The name of the vaccine associated with the contract
'              aNumberOfDoses - The contracts have a minimum order amount.
'                               Contracts are selected based on the number
'                               of doses ordered versus the minimum number
'                               required for the bulk order.
'
' Exceptions:
'
' CHANGE HISTORY
' Request ID  Date        Author          Description
' ------------------------------------------------------------------------
' R1812:D4358 09/21/2004  Stephen Nelson  Release Tulane - Created function.
'#########################################################################
Private Function getContractDetails( _
                                    ByVal aShipmentDate As String, _
                                    ByVal aVaccine As String, _
                                    ByVal aNumberOfDoses As Long, _
                                    ByVal aMfg As String _
) As Contract

    Dim recordset As ADODB.recordset
    Dim query As String
    Dim rowCount As Long  ' Number of rows returned as results of the query
    
    Dim returnContract As Contract
    
    Set recordset = CreateObject("ADODB.Recordset")
    
    ' Query the table for the county name associated with the zip code.
    ' If there is no county name, return vbNullString.
    query = "SELECT * FROM pvaccref WHERE ltrim(rtrim(vaccine)) == '" & aVaccine & "' "
    query = query & "AND ({" & aShipmentDate & "} BETWEEN begin AND end) "
    query = query & " and maker == '" & aMfg & "' "
    query = query & " AND locactiv = .F."
    Debug.Print query
    
    recordset.Open query, Connection, adOpenKeyset, adLockReadOnly, adCmdText
    rowCount = recordset.recordCount
    
    If (rowCount > 0) Then
        ' If there are more than one, use the first record.
        With returnContract
            .vaccine = Trim(recordset.Fields.Item(0))
            .maker = Trim(recordset.Fields.Item(1))
            .begin = recordset.Fields.Item(2)
            .end = recordset.Fields.Item(3)
            .minbulk = recordset.Fields.Item(4)
            .unitsize = recordset.Fields.Item(5)
            .pkgsize = recordset.Fields.Item(6)
            .ndcno = Trim(recordset.Fields.Item(7))
            .cost = recordset.Fields.Item(8)
            .contractid = Trim(recordset.Fields.Item(9))
            .sel_maker = Trim(recordset.Fields.Item(10))
            .dos_wind = Trim(recordset.Fields.Item(11))
            .excfunds = Trim(recordset.Fields.Item(12))
            .descrip = Trim(recordset.Fields.Item(13))
        End With
    Else
        RaiseError VM_CONTRACT_TABLE_ERROR_NUMBER, _
           VM_CONTRACT_TABLE_ERROR_MESSAGE
    End If
    
    CloseRecordSet recordset
    Set recordset = Nothing
    
    getContractDetails = returnContract
    
Exit Function

ErrorHandler:

    With recordset
        If .state = adStateOpen Then
            .Close
        End If
    End With
    
    Set recordset = Nothing
    
    Err.Raise Err
    
End Function

'#########################################################################
' Function Name: getCountyName
'
' Description:   Returns the name of the county where the town resides that
'                is identified by the zip code.
'
' Arguments:     aZipCode   - A zip code of a identified in the table
'                             ZIPCODES.  Uses the first five characters
'                             in the string - assuming these five are a
'                             five-digit zip code.
'
' Returns:       String     - County name if one exists; vbNullString if the
'                             zip code does not exist.
'
' Exceptions:
'
' CHANGE HISTORY
' Request ID  Date        Author          Description
' ------------------------------------------------------------------------
' R1812:D4358 09/21/2004  Stephen Nelson  Release Tulane - Created function.
'#########################################################################
Private Function getCountyName(ByVal aZipCode As String) As String
    
    Dim recordset As ADODB.recordset
    Dim query As String
    Dim rowCount As Long  ' Number of rows returned as results of the query
    Dim countyName As String
    
    Set recordset = CreateObject("ADODB.Recordset")
    
    ' Query the table for the county name associated with the zip code.
    ' If there is no county name, return vbNullString.
    query = "SELECT DISTINCT cntyname "
    query = query & "FROM zipcodes "
    query = query & "WHERE zip = '" & Left(aZipCode, 5) & "' "
    
    Debug.Print query
    
    recordset.Open query, Connection, adOpenKeyset, adLockReadOnly, adCmdText
    rowCount = recordset.recordCount
    
    If (rowCount = 1) Then
        getCountyName = Trim(recordset.Fields.Item(0))
    Else
        getCountyName = vbNullString
    End If
    
    CloseRecordSet recordset
    Set recordset = Nothing
    
Exit Function

ErrorHandler:

    With recordset
        If .state = adStateOpen Then
            .Close
        End If
    End With
    
    Set recordset = Nothing
    
    Err.Raise Err
    
End Function

'#########################################################################
' Function Name: getNextID
'
' Description:   Returns the next ID for the table provided
'
' Arguments:     aTableName - The name of the table with a maximum ID used
'                             stored in the NEXTID table.
'
' Returns:       iNextID from NextID for the given table name
'
' Exceptions:    20096 - Table name does not exist in NextID
'                20097 - More than one row in NextID matched the criteria
'
' CHANGE HISTORY
' Request ID  Date        Author          Description
' ------------------------------------------------------------------------
' R1812:D4358 09/17/2004  Stephen Nelson  Release Tulane - Created function.
'#########################################################################
Private Function getNextID(ByVal aTableName As String) As Long
    
    Dim recordset As ADODB.recordset
    Dim query As String
    Dim rowCount As Long  ' Number of rows returned as results of the query
    Dim iNextID As Long   ' Value in NextID returned from the query
    
    Set recordset = CreateObject("ADODB.Recordset")
    
    ' Query the table for the value associated with the tablename.
    ' If there is no tablename to match the one passed in, raise
    ' an exception.
    query = "SELECT inextid "
    query = query & "FROM Nextid "
    query = query & "WHERE ltrim(rtrim(upper(ctablename))) = '" & UCase(aTableName) & "' "
    
    Debug.Print query
    
    recordset.Open query, Connection, adOpenKeyset, adLockReadOnly, adCmdText
    rowCount = recordset.recordCount
    
    If (rowCount = 0) Then
        RaiseError 20096, _
                    aTableName & " does not exist in the NextID table."
    ElseIf (rowCount > 1) Then
        RaiseError 20096, _
                    "More than one instance of " & aTableName & " exists in the NextID table."
    End If
    
    iNextID = recordset.Fields.Item(0) + 1
    
    CloseRecordSet recordset
    
    ' Update the NextID table with the new value.
    query = "UPDATE nextid "
    query = query & "SET inextid  = " & iNextID & " "
    query = query & "WHERE ltrim(rtrim(upper(ctablename))) = '" & UCase(aTableName) & "' "

    Debug.Print query
    
    recordset.Open query, Connection, adOpenKeyset, adLockReadOnly, adCmdText

    ' Return the value to the calling function.
    getNextID = iNextID
    
    CloseRecordSet recordset
    Set recordset = Nothing
    
Exit Function

ErrorHandler:

    With recordset
        If .state = adStateOpen Then
            .Close
        End If
    End With
    
    Set recordset = Nothing
    
    Err.Raise Err
End Function

'#########################################################################
' Function Name: getDistribStatusCode
'
' Description:   The status code
'
' Arguments:
'
' Returns:
'
' Exceptions:
'
' This is an attempt to reverse engineer the status code used in the
' distrib table.
'
' CHANGE HISTORY
' Request ID  Date        Author          Description
' ------------------------------------------------------------------------
' R1812:D4358 09/17/2004  Stephen Nelson  Release Tulane - Created function.
'#########################################################################
Private Function getDistribStatusCode(ByVal anActionCode As Long, Optional ByVal anAdjustmentType As Boolean = False) As String

    Dim aStatusCode As String
    
    Select Case anActionCode
    Case 1
        If IsMissing(anAdjustmentType) Or (anAdjustmentType = False) Then
            ' Distributions from State inventory
            aStatusCode = "Di"
        Else
            ' Adjustments to State inventory - Subtract
            aStatusCode = "Aj"
        End If
    Case 2
        If IsMissing(anAdjustmentType) Or (anAdjustmentType = False) Then
            ' Returned by Provider in a viable state
            aStatusCode = "Re"
        Else
            ' Adjustments to State inventory - Add
            aStatusCode = "Aj"
        End If
    Case 3
        ' Spoilage reported by Provider
        aStatusCode = "Sp"
    Case 4
        ' Expiration reported by Provider
        aStatusCode = "Ex"
    Case 5
        ' Lost or damaged in transit to Provider
        aStatusCode = "Lo"
    Case 6
        ' Failure to store properly upon recipt by Provider
        aStatusCode = "Im"
    Case 7
        ' Refrigeration failure reported by Provider
        aStatusCode = "Fa"
    Case 8
        ' Transferred between Providers in a viable state
        aStatusCode = "Tr"
    Case 11
        ' Lost or unaccounted for in Provider inventory
        aStatusCode = "Ac"
    Case 12
        ' Other - Not Usable, reported by Provider
        aStatusCode = "Us"
    End Select

    getDistribStatusCode = aStatusCode
    
End Function
    
'#########################################################################
' Function Name: manufacturerProviderOrderRead
'
' Description: This is a specific version of the general stock table
'              read query that requires specific arguments.  In order to
'              query the stock table for provider orders, it is necessary
'              to first check that the required arguments are provided.
'              Therefore, this function checks for the required arguments
'              and then calls the stockTableRead function for which
'              all arguments are optional.
'              Note that if a Shipment End Date is specified then
'              the query is constructed to return those rows with
'              "Datein" values between the two dates specified.
' Arguments:   PIN - Provider Identification Number
'              Vaccine - Vaccine name in order
'              Lot - Lot number,
'              Shipment Begin Date - Date shipped, coresponds to datein colum
'                                    in the stock table
'              Shipment End Date (Optional) - creates a range of shipment dates
'                                   from Shipment begin date to Shipment end
'                                   date corresponding to datein column in the
'                                   stock table
'
' Exceptions:  VM_NULL_PROVIDER_PIN,
'              VM_NULL_VACCINE_NAME,
'              VM_NULL_LOTNUMBER,
'              VM_NULL_SHIPMENT_DATE
'#########################################################################
Public Function manufacturerProviderOrderRead( _
            ByVal aPIN As String, _
            ByVal aShipmentBeginDate As String, _
            Optional ByVal aVaccine As String, _
            Optional ByVal aLotNumber As String, _
            Optional ByVal aShipmentEndDate As String) _
            As cResultSet

On Error GoTo ErrorHandler

    App.LogEvent "Begin: manufacturerProviderOrderRead()", vbLogEventTypeInformation

   'Check all arguments to be sure they are not null
   
   If ValidateNullString(aPIN) = True Then
      RaiseError VM_NULL_PROVIDER_PIN_NUMBER, _
                  VM_NULL_PROVIDER_PIN_MESSAGE
                  
   ElseIf ValidateNullString(aShipmentBeginDate) = True Then
      RaiseError VM_NULL_SHIPMENT_DATE_NUMBER, _
                  VM_NULL_SHIPMENT_DATE_MESSAGE
      
   End If
      
    aPIN = UCase(aPIN)
    aShipmentBeginDate = UCase(aShipmentBeginDate)
    
    If IsMissing(aVaccine) = False Then
        aVaccine = UCase(aVaccine)
    End If
        
    If IsMissing(aLotNumber) = False Then
        aLotNumber = UCase(aLotNumber)
    End If
    
    If IsMissing(aShipmentEndDate) = False Then
        aShipmentEndDate = UCase(aShipmentEndDate)
    End If
    
    'Call generic stock table query
   
    Set manufacturerProviderOrderRead = stockTableRead(aPIN, _
                                    aVaccine, _
                                    aLotNumber, _
                                    aShipmentBeginDate, _
                                    aShipmentEndDate)
   App.LogEvent "End: manufacturerProviderOrderRead()", vbLogEventTypeInformation
   Exit Function
ErrorHandler:
    Dim desc As String
    Dim code As Long
    desc = Err.Description
    code = Err.Number
    
    App.LogEvent "Problem: In manufacturerProviderOrderRead() " & desc, vbLogEventTypeError
    
    Err.Raise code, "VACMAN DLL", desc
                   
            
End Function
'#########################################################################
' Function Name: stockTableRead
'
' Description:  Goes to the VACMAN database for order data.
'               This function constructs a SQL query to be run against
'               the VACMAN database and return values from the stock table.
'               All arguments are optional, and with no arguments the
'               function will return the entire VACMAN stock table.
'              Argument values are added to the where clause of the query,
'              and limits the results to those where the row has the
'              given value for the field specified
'
'
' Arguments:   Optional PIN  - stock table column Pin,
'              Optional Vaccine Name - stock table column Vaccine,
'              Optional Lot Number - stock table column Lot,
'              Optional Shipment Begin Date - stock table column Datein
'              Optional Shipment End Date - creates date range of values in
'                                           stock table column Datein between
'                                           Shipment Begin Date and Shipment
'                                           End Date
'(With no arguments, this function will return the entire stock table.
'  The arguments limit which results are returned.)
'Returns:      The following are the column names in the stock table
'              from which data is returned into the cRecordSet.  In
'              the final cResultSet, these columns names compose Cne collection
'              (cResultSet.Headers -- the Headers Collection), while the data
'              returned composes the Data Collection, cResultSet.Data.
'              Columns:
'              Pin,
'              Datein,
'              Doses,
'              Lot,
'              Vaccine,
'              Maker,
'              Expiry
'
' Exceptions:
'
' CHANGE HISTORY
' Request Id  Date        Author          Description
' ------------------------------------------------------------------------
' R1352       11/05/2001  Stephen Nelson  ODBC 6.0 does not work with the
'                                         DateValue() function.  Replaced
'                                         with brackets {}.
' IMMPACT-529 06/12/2007  Mark Fleming    Change call to ValidateAgainstVaccRefTable
'                                         to exclude Pin
' IMMPACT-684 08/17/2007  Matt Martin     Change call to access info of
'                                         shipped orders
'#########################################################################
Public Function stockTableRead( _
            Optional ByVal aPIN As String, _
            Optional ByVal aVaccine As String, _
            Optional ByVal aLotNumber As String, _
            Optional ByVal aShipmentBeginDate As String, _
            Optional ByVal aShipmentEndDate As String) _
            As cResultSet

On Error GoTo ErrorHandler
    App.LogEvent "Begin: stockTableRead()", vbLogEventTypeInformation

'Declare local variables
Dim readRecordSet As ADODB.recordset
Dim isPINValid As Boolean
Dim SQLString As String
Dim whereClauseSQL As String
   
   'Create recordset object
   
   Set readRecordSet = CreateObject("ADODB.Recordset")
   
   'Validate Provider PIN, by checking that it corresponds
   'to a provider
   
   If ValidateNullString(aPIN) = False Then
      isPINValid = ValidateProviderPIN(aPIN, True, Connection)
   End If

   'Validate that the vaccine exists if one was passed in
   
    If ValidateNullString(aVaccine) = False Then
      ValidateAgainstpVaccRefTable aVaccine, Connection
    
   End If
   
   'Validate that dates passed in are valid
   
   If ValidateNullString(aShipmentBeginDate) = False Then
      If IsDate(aShipmentBeginDate) = False Then
         RaiseError VM_INVALID_SHIPMENT_BEGIN_DATE_NUMBER, _
                     VM_INVALID_SHIPMENT_BEGIN_DATE_MESSAGE
      End If
   End If
   
   If ValidateNullString(aShipmentEndDate) = False Then
      If ValidateNullString(aShipmentBeginDate) = True Then
         RaiseError VM_INVALID_DATE_RANGE_NUMBER, _
                     VM_INVALID_DATE_RANGE_MESSAGE
                     
      ElseIf IsDate(aShipmentEndDate) = False Then
         RaiseError VM_INVALID_SHIPMENT_END_DATE_NUMBER, _
                     VM_INVALID_SHIPMENT_END_DATE_MESSAGE
                  
      ElseIf DateValue(aShipmentEndDate) < DateValue(aShipmentBeginDate) Then
         RaiseError VM_INVALID_DATE_RANGE_NUMBER, _
                     VM_INVALID_DATE_RANGE_MESSAGE
                  
                  
      End If
   End If
   
   'Compose SQL string
   
    SQLString = "SELECT Pin, Datein, Doses, Lot, Vaccine, Maker, Expiry" & _
    " FROM Stock"
    
   'Add where clauses to SQL string if values exist
   whereClauseSQL = addStringToWhereClause(aVaccine, whereClauseSQL, "Vaccine")
   whereClauseSQL = addStringToWhereClause(aPIN, whereClauseSQL, "Pin")
   If ValidateNullString(aLotNumber) = False Then
      If ValidateNullString(whereClauseSQL) = True Then
         whereClauseSQL = " WHERE "
      Else
         whereClauseSQL = whereClauseSQL & " AND "
      End If
   
      whereClauseSQL = whereClauseSQL & " ltrim(rtrim(strtran(lot,ltrim(rtrim('-')),''))) = '" & Replace(aLotNumber, "-", "") & "' "
                                 
   End If
   
   'If both Shipment Begin Date and Shipment End Date are provided, they
   'are intended to create a date range
   
   If ValidateNullString(aShipmentBeginDate) = False Then
      If ValidateNullString(whereClauseSQL) = True Then
         whereClauseSQL = " WHERE "
      Else
         whereClauseSQL = whereClauseSQL & " AND "
      End If
      If ValidateNullString(aShipmentEndDate) = False Then
         ''' R1272 whereClauseSQL = whereClauseSQL & " Datein BETWEEN DateValue( '" & aShipmentBeginDate & "') " & _
         ''' R1272             " AND DateValue( '" & aShipmentEndDate & "')"
         whereClauseSQL = whereClauseSQL & " Datein BETWEEN {" & aShipmentBeginDate & "} " & _
                     " AND {" & aShipmentEndDate & "} "
      Else
         ''' R1272 whereClauseSQL = whereClauseSQL & " Datein = DateValue('" & aShipmentBeginDate & "' )"
         whereClauseSQL = whereClauseSQL & " Datein = {" & aShipmentBeginDate & "} "
      End If
   End If
   
   If ValidateNullString(whereClauseSQL) = True Then
      whereClauseSQL = " WHERE "
   Else
      whereClauseSQL = whereClauseSQL & " AND "
   End If
   
   'Specify that only shipped orders are to be included
   whereClauseSQL = whereClauseSQL & " tracking != ' ' "
   whereClauseSQL = whereClauseSQL & " and lot != ' ' "

   'Construct SQL string
   
   SQLString = SQLString & whereClauseSQL
   SQLString = SQLString & " order by datein desc "
   
   'Open recordset
   'Note that if the connection is not open the Connection property will open it
   
   readRecordSet.Open SQLString, Connection, adOpenKeyset, adLockReadOnly, adCmdText
    
   Set stockTableRead = convertRecordSetToResultSet(readRecordSet)
    
   'Clean up objects
   CloseRecordSet readRecordSet
   Set readRecordSet = Nothing
   App.LogEvent "End: stockTableRead()", vbLogEventTypeInformation
   Exit Function

    
ErrorHandler:
            With readRecordSet
                If .state = adStateOpen Then
                    .Close
                End If
            End With
            Set readRecordSet = Nothing
            Dim desc As String
            Dim code As Long
            desc = Err.Description
            code = Err.Number
    
            App.LogEvent "Problem: In stockTableRead() " & desc, vbLogEventTypeError
    
            Err.Raise code, "VACMAN DLL", desc
                   
            
End Function
 '#########################################################################
' Function Name: vaccineTableRead
'
' Description: Gets the list of all vaccines in the vaccref table from
'              'the database
' Arguments:
'
'
' Returns:     Vaccine Names from the vaccine column in the vaccref table
'              in a cResultSet (Headers collection will
'              just have one value for the column ("Vaccine") being
'              returned, and the Data collection will have all of the
'              vaccine names
'
' Exceptions:  None
' CHANGE HISTORY
' Request Id      Date          Author          Description
' ----------------------------------------------------------------------------
' IMMPACT-529    06/08/2007    Mark Fleming    Change from using vaccref table
'                                              to pvaccref and Nonfedvac tables.
'                                              These new tables replaced vaccref
'                                              in Vacman 4.0
'#########################################################################
Public Function vaccineReferenceTableRead() _
        As cResultSet
        
On Error GoTo ErrorHandler
    App.LogEvent "Begin: vaccineReferenceTableRead()", vbLogEventTypeInformation

Dim readRecordSet As ADODB.recordset
            
Dim SQLString As String

   'Create recordset
   
   Set readRecordSet = CreateObject("ADODB.Recordset")
   
   'Write SQL string
   
   SQLString = "Select Distinct Vaccine" & _
   " From pVaccref"
   
   'Query the database.  If the Connection is not open, the Connection property will open it
   
   readRecordSet.Open SQLString, Connection, adOpenKeyset, adLockReadOnly, adCmdText
   
   'Convert the adoRecordSet into a cResultSet Object (a Collection of Collections),
   'so that the connection to the database can be closed during datamanipulation
   
   Set vaccineReferenceTableRead = convertRecordSetToResultSet(readRecordSet)
  
   CloseRecordSet readRecordSet
   Set readRecordSet = Nothing
   App.LogEvent "End: vaccineReferenceTableRead()", vbLogEventTypeInformation
   Exit Function

    
ErrorHandler:
            With readRecordSet
                If .state = adStateOpen Then
                    .Close
                End If
            End With
            Set readRecordSet = Nothing
            Dim desc As String
            Dim code As Long
            desc = Err.Description
            code = Err.Number
    
            App.LogEvent "Problem: In vaccineReferenceTableRead() " & desc, vbLogEventTypeError
    
            Err.Raise code, "VACMAN DLL", desc
                   
End Function
'#########################################################################
' Function Name: inventoryOnHandRead
'
' Description:    Returns a list of the inventory on Hand -- values from
'                 the remain column in the lots table.
'
' Arguments:   Depot PIN,
'              Vaccine Name
'
' Returns:     Data from the Lot, Expiry, Maker, Order and Remain columns
'              of the lot table, where the vaccine name is the value passed
'              in as a parameter
'
' Exceptions:  VM_NULL_VACCINE_NAME
'               VM_NULL_DEPOT_PIN
'
' CHANGE HISTORY
' Request Id  Date        Author          Description
' ------------------------------------------------------------------------
' R1352       11/05/2001  Stephen Nelson  ODBC 6.0 does not work with the
'                                         DateValue() function.  Replaced
'                                         with brackets {}.
' IMMPACT-529 06/12/2007  Mark Fleming    Change call to ValidateAgainstVaccRefTable
'                                         to exclude Pin.
'                                         Changed SQL query to usee new pvaccref
'                                         table instead of vaccref.
'#########################################################################
Public Function inventoryOnHandRead( _
        ByVal aDepotPIN As String, _
        Optional ByVal aVaccine As String) _
        As cResultSet
        
On Error GoTo ErrorHandler
    App.LogEvent "Begin: inventoryOnHandRead()", vbLogEventTypeInformation

Dim readRecordSet As ADODB.recordset
Dim SQLString As String
Dim whereClauseSQL As String
    
   Set readRecordSet = CreateObject("ADODB.Recordset")
   
   'Validate Syntax - isNull()
   
   If ValidateNullString(aDepotPIN) = True Then
      Err.Raise VM_NULL_DEPOT_PIN_NUMBER, _
                  App.EXEName, _
                  VM_NULL_DEPOT_PIN_MESSAGE
   End If
   
    aDepotPIN = UCase(aDepotPIN)
    
    If IsMissing(aVaccine) = False Then
        aVaccine = UCase(aVaccine)
    End If
      
   'Validate values
   
   ValidateDepotPIN aDepotPIN, Connection
   
   If ValidateNullString(aVaccine) = False Then
      ValidateAgainstpVaccRefTable aVaccine, Connection
   End If
   
   'Create SQL string
   
   SQLString = "Select l.Vaccine, l.Lot, l.Expiry, l.Maker, l.Remain, l.Size" & _
      " From Lots l, pvaccref v"
      
   whereClauseSQL = addStringToWhereClause(aVaccine, whereClauseSQL, "l.Vaccine")
   whereClauseSQL = addStringToWhereClause(aDepotPIN, whereClauseSQL, "l.Pin")
   ''' R1272 whereClauseSQL = whereClauseSQL & " AND l.Expiry >= " & " DateValue('" & CStr(Format(Date, "mm/dd/yyyy")) & "')"
   whereClauseSQL = whereClauseSQL & " AND l.Expiry >= " & " {" & CStr(Date) & "} "
   whereClauseSQL = whereClauseSQL & " AND l.Size > 0 "
   whereClauseSQL = whereClauseSQL & " AND l.Remain >= 0 "
   whereClauseSQL = whereClauseSQL & " AND trim(l.Maker) is not NULL"
   whereClauseSQL = whereClauseSQL & " AND trim(l.vaccine) == trim(v.vaccine)"
   whereClauseSQL = whereClauseSQL & " AND v.locactiv = .T."
   whereClauseSQL = whereClauseSQL & " ORDER BY l.Vaccine, l.Lot, l.Expiry"
   SQLString = SQLString & whereClauseSQL
   App.LogEvent SQLString, vbLogEventTypeInformation
   
   'Open RecordSet
   
   readRecordSet.Open SQLString, Connection, adOpenKeyset, adLockReadOnly, adCmdText
   
   Set inventoryOnHandRead = convertRecordSetToResultSet(readRecordSet)

   'Clean up record set
   
   CloseRecordSet readRecordSet
   Set readRecordSet = Nothing
   
   App.LogEvent "End: inventoryOnHandRead()", vbLogEventTypeInformation
   Exit Function

    
ErrorHandler:
      
            With readRecordSet
                If .state = adStateOpen Then
                    .Close
                End If
            End With
            Set readRecordSet = Nothing
            Dim desc As String
            Dim code As Long
            desc = Err.Description
            code = Err.Number
    
            App.LogEvent "Problem: In inventoryOnHandRead() " & desc, vbLogEventTypeError
    
            Err.Raise code, "VACMAN DLL", desc

End Function

'#########################################################################
' Subroutine Name: manufacturerProviderOrderCreateUpdate
'
' Description: This function creates or updates a record in the Stock
' table representing a manufacturer provider order.
'
' Arguments:
'
'           anOrderDate - The date that the order was made.
'
'           aPIN - The PIN of the provider making the order.
'
'           aVaccine - The vaccine being ordered
'
'           aDoseCount - The number of doses in the order
'
'           aFundingSource - The source of funding for the vaccine. Valid
'           funding sources are defined in the funding table.
'           In particular, if the funding source is state,
'           then a State PO number is required.
'
'           anExcessAllowance - This flag indicates whether the order has to be
'           validated against the provider yearly allowance for the vaccine.
'
'           aStatePO - A State Purchase Order Number. Only considered if
'           the funding source of the order has been specified as State.
'
'
' Exceptions:
'           VM_PROVIDER_PIN_NOT_FOUND
'           VM_NULL_ENTRY_DATE
'           VM_DOSES_ERROR
'
' CHANGE HISTORY
' Request Id  Date        Author          Description
' ------------------------------------------------------------------------
' R1352       11/05/2001  Stephen Nelson  ODBC 6.0 does not work with the
'                                         DateValue() function.  Replaced
'                                         with brackets {}.
' R1352       11/30/2001  Stephen Nelson  Modified the INSERT statement
'                                         to remove the single quote characters
'                                         from either side of the cost value.
' R1596       03/04/2002  Joe Bernard     ODBC 6.0 also does not work with
'                                         ltrim and rtrim on numeric or
'                                         date values. Removed these on
'                                         orddate field.
' R1812:D4358 09/30/2004  Stephen Nelson  Manufacturer direct orders are
'                                         now processed through the NEWORDER
'                                         table, and not the STOCK table.
'                                         Made the necessary changes in
'                                         this procedure.
'                                         This change occurred with
'                                         the release of Vacman 3.0.8.
'                                         Also, cleaned up the old code
'                                         that had been commented out from
'                                         past releases.
' IMMPACT-529 06/12/2007  Mark Fleming    Change call to ValidateAgainstVaccRefTable
'                                         to exclude Pin
' IMMPACT-623 07/02/2007  Matt Martin     Pass in manufacturer to distinguish FLU orders
'
'#########################################################################
Public Sub manufacturerProviderOrderCreateUpdate( _
                                ByVal anOrderDate As String, _
                                ByVal aPIN As String, _
                                ByVal aVaccine As String, _
                                ByVal aDoseCount As Long, _
                                ByVal aFundingSource As String, _
                                Optional ByVal anExcessAllowance As String = EXCESS_ALLOW_DEFAULT, _
                                Optional ByVal aStatePO As String, _
                                Optional ByVal aMfg As String _
                                )
            
On Error GoTo ErrorHandler
    App.LogEvent "Begin: manufacturerProviderOrderCreateUpdate()", vbLogEventTypeInformation
    Dim query As String
    Dim isPINValid As Boolean
    Dim recordType As String
    Dim rowCount As Long
    Dim doses As Long
    Dim aVariant As Variant
    Dim fundingSource As String
    Dim statepo As String
    Dim excessAllowance As String
    Dim pkgsize As Long
    Dim cost As String
    
    Dim aContract As Contract  'R1812 Change

    If aDoseCount <= 0 Then
        RaiseError VM_NULL_DOSE_NUMBER, _
                    VM_NULL_DOSE_MESSAGE
    End If

    If ValidateNullString(aFundingSource) Then
        RaiseError VM_NULL_FUNDING_SOURCE_NUMBER, _
                    VM_NULL_FUNDING_SOURCE_MESSAGE
    End If

    anOrderDate = UCase(anOrderDate) '
    aPIN = UCase(aPIN)

    aVaccine = UCase(aVaccine)
    aFundingSource = UCase(aFundingSource)

    If IsMissing(anExcessAllowance) = False Then
        anExcessAllowance = UCase(anExcessAllowance)
    End If

    If IsMissing(aStatePO) = False Then
        aStatePO = UCase(aStatePO)
    End If


    If ValidateNullString(anExcessAllowance) Then
        anExcessAllowance = EXCESS_ALLOW_DEFAULT
    End If

    If ValidateNullString(aStatePO) Then
        aStatePO = ""
    End If

    excessAllowance = anExcessAllowance
    fundingSource = aFundingSource
    statepo = aStatePO

    If ValidateProviderPIN(aPIN, True, Connection) = False Then
        RaiseError VM_PROVIDER_PIN_NOT_FOUND_NUMBER, _
                    VM_PROVIDER_PIN_NOT_FOUND_MESSAGE
    End If

    If ValidateNullString(anOrderDate) = True Then
        RaiseError VM_NULL_MANUFACTURER_ORDER_ENTRY_DATE_NUMBER, _
                    VM_NULL_MANUFACTURER_ORDER_ENTRY_DATE_MESSAGE
    End If

    If IsDate(anOrderDate) = False Then
        RaiseError VM_INVALID_MANUFACTURER_ORDER_DATE_NUMBER, _
                    VM_INVALID_MANUFACTURER_ORDER_DATE_MESSAGE
    End If

    If (StrComp(aVaccine, VARICELLA) = 0) Then
        If ValidateProvideraVaricellaEligibility(aPIN, Connection) = False Then
           RaiseError VM_PROVIDER_NOT_ELIGIBLE_FOR_VAR_NUMBER, _
                        VM_PROVIDER_NOT_ELIGIBLE_FOR_VAR_MESSAGE
        End If
    End If

    ValidateAgainstpVaccRefTable aVaccine, Connection

    ValidateFundingCodeandPO fundingSource, statepo, Connection

    ValidateExcessAllowance anExcessAllowance

    If True = ValidateDuplicateManufacturerOrder(anOrderDate, _
                                        aPIN, _
                                        aVaccine, _
                                        aFundingSource, _
                                        Connection) Then

        doses = ManufacturerOrderDoses(anOrderDate, aPIN, aVaccine, aFundingSource, Connection)

        doses = doses + aDoseCount

        ' R1812:D4358 Start Changes
        aContract = getContractDetails(anOrderDate, aVaccine, aDoseCount, aMfg)
        
'''        ValidateAgainstVaccineContractTable anOrderDate, aVaccine, doses, _
'''                                        pkgsize, cost, Connection

        If (StrComp(aVaccine, "FLU") = 0) Or StrComp(aVaccine, "FLU-PF") = 0 Then
            query = "UPDATE influenza "
        Else
            query = "UPDATE neworder "
        End If
    
        query = query & "SET orddose = " & aDoseCount & ", "
        query = query & "fdose1 = " & aDoseCount & ", "
        query = query & "chgdate = {" & Date & "}, "
        query = query & "userid = '" & VACMAN_DLL_USER & "', "
        query = query & "size = " & aContract.pkgsize & ", "
        query = query & "cost = " & aContract.cost & " "
        query = query & "WHERE ltrim(rtrim(pin)) = '" & aPIN & "' "
        query = query & "AND ltrim(rtrim(vaccine)) = '" & aVaccine & "' "
        query = query & "AND orddate = {" & anOrderDate & "} "
        query = query & "AND ltrim(rtrim(fcode1)) = '" & aFundingSource & "'"

    Else
        
        aContract = getContractDetails(anOrderDate, aVaccine, aDoseCount, aMfg)
        
'''        ValidateAgainstVaccineContractTable anOrderDate, aVaccine, doses, _
'''                                        pkgsize, cost, Connection

        If (StrComp(aVaccine, "FLU") = 0) Or (StrComp(aVaccine, "FLU-PF") = 0) Then
            query = "INSERT INTO influenza( "
        Else
            query = "INSERT INTO neworder( "
        End If
        query = query & "ordpin, "
        query = query & "rectype, "
        query = query & "pin, "
        query = query & "orddate, "
        query = query & "vaccine, "
        query = query & "orddose, "
        query = query & "fcode1, "
        query = query & "fdose1, "
        query = query & "size, "
        query = query & "cost, "
        query = query & "maker, "
        query = query & "contract, "
        query = query & "ndcno, "
        query = query & "chgdate, "
        query = query & "userid, "
        query = query & "descrip "
        query = query & ")"
        
        query = query & " VALUES( "
        If (StrComp(aVaccine, VARICELLA) = 0) Then
            query = query & "'MERCKC', "                   ' ordpin
        Else
            query = query & " '', "
        End If
        If StrComp(aVaccine, VARICELLA) = 0 Then
            query = query & "'" & MANUFACTURER_ORDER & "', " ' rectype
        Else
            query = query & " '5', "
        End If
        query = query & "'" & aPIN & "', "                  ' sitepin
        query = query & "{" & anOrderDate & "}, "
        query = query & "'" & aVaccine & "',"
        query = query & aDoseCount & ", "
        query = query & "'" & aFundingSource & "', "
        query = query & aDoseCount & ", "
        query = query & aContract.pkgsize & ", "
        query = query & aContract.cost & ", "
        query = query & "'" & aContract.maker & "', "      ' maker
        query = query & "'" & aContract.contractid & "', " ' contract
        query = query & "'" & aContract.ndcno & "', "      ' ndcno
        query = query & "{" & anOrderDate & "}, "                 ' chgdate
        query = query & "'" & VACMAN_DLL_USER & "', "       ' userid
        If StrComp(aVaccine, VARICELLA) = 0 Then
            query = query & " '' "
        Else
            query = query & "'" & aContract.descrip & "'"
        End If
        query = query & ")"
        ' R1812:D4358 End Changes
    End If
    Debug.Print query
    Connection.Execute query
    App.LogEvent "End: manufacturerProviderOrderCreateUpdate()", vbLogEventTypeInformation
Exit Sub

ErrorHandler:
   
    Debug.Print Err.source
    Debug.Print Err.Description
    Debug.Print Err.Number
    Debug.Print Err.HelpFile
    Debug.Print Err.HelpContext
    Dim desc As String
    Dim code As Long
    desc = Err.Description
    code = Err.Number
    
    App.LogEvent "Problem: In manufacturerProviderOrderCreateUpdate() " & desc, vbLogEventTypeError
    
    Err.Raise code, "VACMAN DLL", desc
    
End Sub

'#########################################################################
' Subroutine Name: providerProfileUpdate
'
' Description: Creates or updates a record in the provider table. A
' classification code must always be valid when given. In particular
' a classification code must be given when creating a new provider
' record.
'
'
' Arguments:
'           aPIN - The pin of the provider whose profile is being updated
'
'           aFacilityLastName - Last name of a private provider OR the
'           entire name of the facility.
'
'           aShippingContact - Person to contact for information or about
'           or questions about vaccine shipments or deliveries.
'
'           aShippingAddress1 - First line of the provider shipping address.
'
'           aShippingAddress2 - Second line of the provider shipping address.
'
'           aShippingCity - Shipping address city.
'
'           aShippingState - Shipping address state.
'
'           aShippingZipCode - Shiping address zip code.
'
'           aShippingInstructions - Shipping instructions.
'
'           aShippingPhoneNumber  -  Shipping Phone Number         IMMPACT-553
'
'           aShippingFaxNumber  -  Shipping Fax Number             IMMPACT-553
'
'           aMailContact - Person to contact for questions or problems about vaccine issues.
'
'           aMailAddress1 - First line of the provider mailing address.
'
'           aMailAddress2 - Second line of the provider mailing address.
'
'           aMailCity - Mailing address city.
'
'           aMailState - Mailing address state.
'
'           aMailZipCode - Mailing address zip code.
'
'           aMailPhoneNumber - Mailing phone number.               IMMPACT-553
'
'           aMailFaxNumber - Mailing fax number.                   IMMPACT-553
'
'           aVaricellaEligibilityStatus - Specifies whether provider is eligible to receive varicella.
'
'           Optional aClassificationCode - Provider classification code. This value is verified
'           against valid codes in the database.
'
'           Optional aVFCCertificationDate - Date on which provider was VFC certified.
'
'           Optional aPhoneExtension - Extension to the provider phone number.
'
'           Optional aFirstName - First name of private provider.
'
'           Optional aMiddleInitial - Middle initial of private provider.
'
'           Optional aTitle - Title of private provider.
'
'           Optional aParentProviderID - PIN for a parent rovider record of the current provider.
'
'           Optional anAdditionalID - User-defined secondary identification code for the provider.
'
'           Optional anActiveStatus - Specifies whether provider is active.
'
'           Optional aSubdivision - User-defined name of the project jurisdictional subdivision.
'
'           Optional aCategory1 - User-defined field.
'
'           Optional aCategory2 - User-defined field.
'
'           Optional aCategory3 - User-defined field.
'
'
' Exceptions:
'           VM_NULL_PROVIDER_NAME
'           VM_NULL_SHIPPING_CONTACT
'           VM_INVALID_PHONE_NUMBER
'           VM_INVALID_FAX_NUMBER
'           VM_MISSING_CLASSIFICATION_CODE
'           VM_INVALID_CLASSIFICATION_CODE
'
' CHANGE HISTORY
' Request Id  Date        Author          Description
' ------------------------------------------------------------------------
' R1352       11/05/2001  Stephen Nelson  ODBC 6.0 does not work with the
'                                         DateValue() function.  Replaced
'                                         with brackets {}.
'                                         Changed the reference to the note
'                                         field. No longer place it in double
'                                         quotes.
' R1812:D4358 09/21/2004  Stephen Nelson  Release Tulane
'                                         Update this procedure to reflect
'                                         the changes made to the provider
'                                         table with the release of
'                                         Vacman 3.0.8.  Added the county
'                                         name, physician count (default to
'                                         zero), the record creation
'                                         date, and a provider id.
' IMMPACT-553 06/14/2007  Mark Fleming    Changed parameters to include both
'                                         shipping and mailing phone and fax
'                                         numbers.
' IMMPACT-626 07/03/2007  Matt Martin     Dont overwrite county with a blank
' IMMPACT-636 07/05/2007  Matt Martin     Mailing phone is not required in vacman
'#########################################################################
Public Sub providerProfileUpdate( _
            ByVal aPIN As String, _
            ByVal aFacilityLastName As String, _
            ByVal aShippingContact As String, _
            ByVal aShippingAddress1 As String, ByVal aShippingAddress2 As String, _
            ByVal aShippingCity As String, ByVal aShippingState As String, _
            ByVal aShippingZipCode As String, _
            ByVal aShippingInstructions As String, _
            ByVal aShippingPhoneNumber As String, _
            ByVal aShippingFaxNumber As String, _
            ByVal aMailContact As String, _
            ByVal aMailAddress1 As String, ByVal aMailAddress2 As String, _
            ByVal aMailCity As String, ByVal aMailState As String, _
            ByVal aMailZipCode As String, _
            ByVal aMailPhoneNumber As String, ByVal aMailFaxNumber As String, _
            ByVal aVaricellaEligibilityStatus As Boolean, _
            Optional ByVal aClassificationCode As Variant, _
            Optional ByVal aVFCCertificationDate As Variant, _
            Optional ByVal aPhoneExtension As Variant, _
            Optional ByVal aFirstName As Variant, Optional ByVal aMiddleInitial As Variant, _
            Optional ByVal aTitle As Variant, _
            Optional ByVal aParentProviderID As Variant, Optional ByVal anAdditionalID As Variant, _
            Optional ByVal anActiveStatus As Variant, _
            Optional ByVal aSubdivision As Variant, Optional ByVal aCategory1 As Variant, _
            Optional ByVal aCategory2 As Variant, Optional ByVal aCategory3 As Variant)
            
On Error GoTo ErrorHandler
            App.LogEvent "Begin: providerProfileUpdate()", vbLogEventTypeInformation
            Dim query As String
            Dim setClause As String
            Dim isPINValid As Boolean
            Dim classificationCode As String
            Dim varicellaEligibilityStatus As String
            Dim enrollmentDataChangeDate As Date
            ' R1812:D4358 Change Dim userID As String
            Dim currentDate As Date
            ' R1812:D4358 Start Change
            Dim physicianCount As Long
            Dim createDate As Date
            Dim countyName As String
            Dim provID As Long
            ' R1812:D4358 End Change
    
            currentDate = Date
            
            aPIN = UCase(aPIN)
            aFacilityLastName = UCase(aFacilityLastName)
            aShippingContact = UCase(aShippingContact)
            aShippingAddress1 = UCase(stripInvalidCharacters(aShippingAddress1))
            aShippingAddress2 = UCase(stripInvalidCharacters(aShippingAddress2))
            aShippingCity = UCase(stripInvalidCharacters(aShippingCity))
            aShippingState = UCase(stripInvalidCharacters(aShippingState))
            aShippingZipCode = UCase(stripInvalidCharacters(aShippingZipCode))
            aShippingInstructions = UCase(stripInvalidCharacters(aShippingInstructions))
            aShippingPhoneNumber = UCase(aShippingPhoneNumber)
            aShippingFaxNumber = UCase(aShippingFaxNumber)
            aMailContact = UCase(aMailContact)
            aMailAddress1 = UCase(stripInvalidCharacters(aMailAddress1))
            aMailAddress2 = UCase(stripInvalidCharacters(aMailAddress2))
            aMailCity = UCase(stripInvalidCharacters(aMailCity))
            aMailState = UCase(stripInvalidCharacters(aMailState))
            aMailZipCode = UCase(stripInvalidCharacters(aMailZipCode))
            aMailPhoneNumber = UCase(aMailPhoneNumber)
            aMailFaxNumber = UCase(aMailFaxNumber)

            If IsMissing(aVFCCertificationDate) = False Then
                aVFCCertificationDate = UCase(aVFCCertificationDate)
            End If

            If IsMissing(aPhoneExtension) = False Then
                aPhoneExtension = UCase(aPhoneExtension)
            End If

            If IsMissing(aFirstName) = False Then
                aFirstName = UCase(aFirstName)
            End If

            If IsMissing(aMiddleInitial) = False Then
                aMiddleInitial = UCase(aMiddleInitial)
            End If

            If IsMissing(aTitle) = False Then
                aTitle = UCase(aTitle)
            End If

            If IsMissing(aParentProviderID) = False Then
                aParentProviderID = UCase(aParentProviderID)
            End If

            If IsMissing(anAdditionalID) = False Then
                anAdditionalID = UCase(anAdditionalID)
            End If

            If IsMissing(anActiveStatus) = False Then
                anActiveStatus = UCase(anActiveStatus)
                If anActiveStatus = "Y" Or anActiveStatus = "N" Then
                Else
                    RaiseError VM_INVALID_ACTIVE_CODE_NUMBER, _
                                VM_INVALID_ACTIVE_CODE_MESSAGE
                End If

            Else
                anActiveStatus = "Y"
            End If

            If IsMissing(aSubdivision) = False Then
                aSubdivision = UCase(aSubdivision)
            End If

            If IsMissing(aCategory1) = False Then
                aCategory1 = UCase(aCategory1)
            End If

            If IsMissing(aCategory2) = False Then
                aCategory2 = UCase(aCategory2)
            End If

            If IsMissing(aCategory3) = False Then
                aCategory3 = UCase(aCategory3)
            End If

            isPINValid = ValidateProviderPIN(aPIN, True, Connection)

            If ValidateNullString(aFacilityLastName) = True Then
                RaiseError VM_NULL_PROVIDER_NAME_NUMBER, _
                            VM_NULL_PROVIDER_NAME_MESSAGE
            End If

            If ValidateNullString(aShippingContact) = True Then
                RaiseError VM_NULL_SHIPPING_CONTACT_NUMBER, _
                            VM_NULL_SHIPPING_CONTACT_MESSAGE
            End If

            ValidateShippingAddress aShippingAddress1, _
                            aShippingAddress2, _
                            aShippingCity, _
                            aShippingZipCode, _
                            aShippingState, _
                            Connection


            If ValidateNullString(aShippingInstructions) = True Then
                aShippingInstructions = NONE_STRING
            End If

            If ValidatePhoneFaxFormat(aShippingPhoneNumber) = False Then
                RaiseError VM_INVALID_SHIP_PHONE_NUMBER_NUMBER, _
                            VM_INVALID_SHIP_PHONE_NUMBER_MESSAGE
            End If

            If ValidateNullString(aShippingFaxNumber) = False Then
                If ValidatePhoneFaxFormat(aShippingFaxNumber) = False Then
                    RaiseError VM_INVALID_SHIP_FAX_NUMBER_NUMBER, _
                                VM_INVALID_SHIP_FAX_NUMBER_MESSAGE
                End If
            End If
            
            If ValidateNullString(aMailPhoneNumber) = False Then
                If ValidatePhoneFaxFormat(aMailPhoneNumber) = False Then
                    RaiseError VM_INVALID_MAIL_PHONE_NUMBER_NUMBER, _
                                VM_INVALID_MAIL_PHONE_NUMBER_MESSAGE
                End If
            End If
            
            If ValidateNullString(aMailFaxNumber) = False Then
                If ValidatePhoneFaxFormat(aMailFaxNumber) = False Then
                    RaiseError VM_INVALID_MAIL_FAX_NUMBER_NUMBER, _
                                VM_INVALID_MAIL_FAX_NUMBER_MESSAGE
                End If
            End If

            If aVaricellaEligibilityStatus = True Then
                varicellaEligibilityStatus = VARICELLA_ELIGIBLE
            Else
                varicellaEligibilityStatus = NOT_VARICELLA_ELIGIBLE
            End If

            ' R1812:D4358 Start Change
            countyName = getCountyName(aShippingZipCode)
            provID = getNextID("Provider")
            ' R1812:D4358 End Change
            
            If (isPINValid = False) Then

                 ' Per CDC, a classification code must always be there and valid
                If IsMissing(aClassificationCode) Then
                    RaiseError VM_MISSING_CLASSIFICATION_CODE_NUMBER, _
                                VM_MISSING_CLASSIFICATION_CODE_MESSAGE
                ElseIf Not ValidateSector(CLng(aClassificationCode), Connection) Then
                    RaiseError VM_INVALID_CLASSIFICATION_CODE_NUMBER, _
                                VM_INVALID_CLASSIFICATION_CODE_MESSAGE
                End If

                'Per CDC, must also make sure that the new pin is neither 999998 or 9999999
                ValidateNewProviderPIN aPIN
                ''' R1812:D4358 Change aPIN = String((PIN_LENGTH - Len(aPIN)), " ") & aPIN
                query = "INSERT INTO provider(pin, "
                query = query & "contact, lastname, "
                query = query & "address, addres2, "
                query = query & "city, state, zipcode, "
                query = query & "ml_contact, "
                query = query & "ml_address, ml_addres2, "
                query = query & "ml_city, ml_state, ml_zipcode, "
                query = query & "note, "  'R1272 Change
                query = query & "phone, fax, codes, "  ' R1272 Change
                query = query & "phone2, fax2, "       ' IMMPACT-553
                ' R1812:D4358 Start Changes
                query = query & "createdate, "
                query = query & "county, "
                query = query & "provid"
                ' R1812:D4358 End Changes
                
                If IsMissing(aClassificationCode) = False Then
                    query = query & ", sector"
                End If

                If IsMissing(aVFCCertificationDate) = False Then
                    query = query & ", datevfc"
                End If

                If IsMissing(aPhoneExtension) = False Then
                    query = query & ", extension"
                End If

                If IsMissing(aFirstName) = False Then
                    query = query & ", firstname"
                End If

                If IsMissing(aMiddleInitial) = False Then
                    query = query & ", initial"
                End If

                If IsMissing(aTitle) = False Then
                    query = query & ", title"
                End If

                If IsMissing(aParentProviderID) = False Then
                    query = query & ", linkpin"
                End If

                If IsMissing(anAdditionalID) = False Then
                    query = query & ", alphaid"
                End If
                If IsMissing(anActiveStatus) = False Then
                    query = query & ", active"
                End If
                If IsMissing(aSubdivision) = False Then
                    query = query & ", subdiv"
                End If
                If IsMissing(aCategory1) = False Then
                    query = query & ", cat1"
                End If
                If IsMissing(aCategory2) = False Then
                    query = query & ", cat2"
                End If

                If IsMissing(aCategory3) = False Then
                    query = query & ", cat3"
                End If

                query = query & ", chgdate, userid"
                query = query & ") "
                
                query = query & "VALUES('" & aPIN & "', '"
                query = query & aShippingContact & "', '" & aFacilityLastName & "', '"
                query = query & aShippingAddress1 & "', '" & aShippingAddress2 & "', '"
                query = query & aShippingCity & "', '" & aShippingState & "', '" & aShippingZipCode & "', '"
                query = query & aMailContact & "', '"
                query = query & aMailAddress1 & "', '" & aMailAddress2 & "', '"
                query = query & aMailCity & "', '" & aMailState & "', '" & aMailZipCode & "', '"
                query = query & aShippingInstructions & "', '"
                query = query & aShippingPhoneNumber & "', '" & aShippingFaxNumber & "', '" & varicellaEligibilityStatus & "', '"  'R1812:D4358 Change
                'IMMPACT-553
                query = query & aMailPhoneNumber & "', '" & aMailFaxNumber & "', "
                ' R1812:D4358 Start Change
                query = query & "{" & createDate & "}, '"
                query = query & countyName & "', "
                query = query & provID & " "
                ' R1812:D4358 End Change
                
                If IsMissing(aClassificationCode) = False Then
                    query = query & ", " & CLng(aClassificationCode) & " "
                End If

                If IsMissing(aVFCCertificationDate) = False Then
                    ''' R1272 query = query & ",datevalue('" & CStr(aVFCCertificationDate) & "')"
                    query = query & ", {" & CStr(aVFCCertificationDate) & "} "
                End If


                If IsMissing(aPhoneExtension) = False Then
                    query = query & ",'" & CStr(aPhoneExtension) & "'"
                End If

                If IsMissing(aFirstName) = False Then
                    query = query & ",'" & CStr(aFirstName) & "'"
                End If

                If IsMissing(aMiddleInitial) = False Then
                    query = query & ",'" & CStr(aMiddleInitial) & "'"
                End If

                If IsMissing(aTitle) = False Then
                    query = query & ",'" & CStr(aTitle) & "'"
                End If

                If IsMissing(aParentProviderID) = False Then
                    query = query & ",'" & CStr(aParentProviderID) & "'"
                End If

                If IsMissing(anAdditionalID) = False Then
                    query = query & ",'" & CStr(anAdditionalID) & "'"
                End If

                If IsMissing(anActiveStatus) = False Then
                    query = query & ",'" & CStr(anActiveStatus) & "'"
                End If

                If IsMissing(aSubdivision) = False Then
                    query = query & ",'" & CStr(aSubdivision) & "'"
                End If

                If IsMissing(aCategory1) = False Then
                    query = query & ",'" & CStr(aCategory1) & "'"
                End If

                If IsMissing(aCategory2) = False Then
                    query = query & ",'" & CStr(aCategory2) & "'"
                End If

                If IsMissing(aCategory3) = False Then
                    query = query & ",'" & CStr(aCategory3) & "'"
                End If

                ''' R1272 query = query & ", datevalue('" & currentDate & "'), '" & VACMAN_DLL_USER & "'"
                query = query & ", {" & currentDate & "}, '" & VACMAN_DLL_USER & "'"
                query = query & ")"
                
                App.LogEvent query, vbLogEventTypeInformation
                
                Debug.Print query
                
                Connection.Execute query
                
                enrollmentDataChangeDate = Date

                enrollmentDataUpdate aPIN, enrollmentDataChangeDate, VACMAN_DLL_USER, Connection

           Else

                setClause = "SET "

                ' now include other attributes conditionally
                If IsMissing(aClassificationCode) = False Then
                    If ValidateSector(CLng(aClassificationCode), Connection) Then
                        setClause = setClause & "sector = " & CLng(aClassificationCode) & ", "
                    Else
                        RaiseError VM_INVALID_CLASSIFICATION_CODE_NUMBER, _
                                VM_INVALID_CLASSIFICATION_CODE_MESSAGE
                    End If
                End If

                If IsMissing(aVFCCertificationDate) = False Then
                    ValidateVFCCertDate CStr(aVFCCertificationDate)
                    ''' R1272 setClause = setClause & "datevfc = datevalue('" & CStr(aVFCCertificationDate) & "'), "
                    setClause = setClause & "datevfc = {" & CStr(aVFCCertificationDate) & "}, "
                End If

                If IsMissing(aPhoneExtension) = False Then
                    setClause = setClause & "extension = '" & CStr(aPhoneExtension) & "', "
                End If

                If IsMissing(aFirstName) = False Then
                    setClause = setClause & "firstname = '" & CStr(aFirstName) & "', "
                End If

                If IsMissing(aMiddleInitial) = False Then
                    setClause = setClause & "initial = '" & CStr(aMiddleInitial) & "', "
                End If

                If IsMissing(aTitle) = False Then
                    setClause = setClause & "title = '" & CStr(aTitle) & "', "
                End If

                If IsMissing(aParentProviderID) = False Then
                    setClause = setClause & "linkpin = '" & CStr(aParentProviderID) & "', "
                End If

                If IsMissing(anAdditionalID) = False Then
                    setClause = setClause & "alphaid = '" & CStr(anAdditionalID) & "', "
                End If

                If IsMissing(anActiveStatus) = False Then
                    If ValidateActiveValue(CStr(anActiveStatus)) Then
                        setClause = setClause & "active = '" & CStr(anActiveStatus) & "', "
                    End If
                End If

                If IsMissing(aSubdivision) = False Then
                    ValidateSubdivision (CStr(aSubdivision)), Connection
                    setClause = setClause & "subdiv = '" & CStr(aSubdivision) & "', "
                End If

                If IsMissing(aCategory1) = False Then
                    setClause = setClause & "cat1 = '" & CStr(aCategory1) & "', "
                End If

                If IsMissing(aCategory2) = False Then
                    setClause = setClause & "cat2 = '" & CStr(aCategory2) & "', "
                End If

                If IsMissing(aCategory3) = False Then
                    setClause = setClause & "cat3 = '" & CStr(aCategory3) & "', "
                End If

                'It is important that this is block of required
                'fields is at the end. Otherwise we would have
                'to keep track of where to put commas

                setClause = setClause & "contact = '" & aShippingContact & "', "
                setClause = setClause & "lastname = '" & aFacilityLastName & "', "
                setClause = setClause & "address = '" & aShippingAddress1 & "', "
                setClause = setClause & "addres2 = '" & aShippingAddress2 & "', "
                setClause = setClause & "city = '" & aShippingCity & "', "
                setClause = setClause & "state = '" & aShippingState & "', "
                setClause = setClause & "zipcode = '" & aShippingZipCode & "', "
                setClause = setClause & "ml_contact = '" & aMailContact & "', "
                setClause = setClause & "ml_address = '" & aMailAddress1 & "', "
                setClause = setClause & "ml_addres2 = '" & aMailAddress2 & "', "
                setClause = setClause & "ml_city = '" & aMailCity & "', "
                setClause = setClause & "ml_state = '" & aMailState & "', "
                setClause = setClause & "ml_zipcode = '" & aMailZipCode & "', "
                setClause = setClause & "note = '" & aShippingInstructions & "', "  'R1272 Change
                'IMMPACT-553
                setClause = setClause & "phone = '" & aShippingPhoneNumber & "', "
                setClause = setClause & "fax = '" & aShippingFaxNumber & "', "
                setClause = setClause & "phone2 = '" & aMailPhoneNumber & "', "
                setClause = setClause & "fax2 = '" & aMailFaxNumber & "', "
                'IMMPACT-553 End
                setClause = setClause & "codes = '" & varicellaEligibilityStatus & "',"
                If countyName <> vbNullString And LenB(countyName) <> 0 Then
                    setClause = setClause & "county = '" & countyName & "', "   'R1812:D4358 Change
                End If
                setClause = setClause & "chgdate = {" & currentDate & "},"  ' R1272 Change
                setClause = setClause & "userid = '" & VACMAN_DLL_USER & "'"
                query = "UPDATE "
                query = query & "provider "
                query = query & setClause
                query = query & "WHERE "
                query = query & "ltrim(rtrim(pin)) = '" & aPIN & "'"

                App.LogEvent query, vbLogEventTypeInformation

                Debug.Print query

                Connection.Execute query

            End If


            App.LogEvent "End: providerProfileUpdate()", vbLogEventTypeInformation

            Exit Sub

ErrorHandler:
            Debug.Print Err.source
            Debug.Print Err.Description
            Debug.Print Err.Number
            Debug.Print Err.HelpFile
            Debug.Print Err.HelpContext
            Dim desc As String
            Dim code As Long
            desc = Err.Description
            code = Err.Number
    
            App.LogEvent "Problem: In providerProfileUpdate() " & desc, vbLogEventTypeError
    
            Err.Raise code, "VACMAN DLL", desc
            
             
End Sub
'#########################################################################
' Subroutine Name: providerInventoryAdjustmentUpdate
'
' Description:
' This subroutine creates or updates provider inventory adjustments.
' Only the adjustments that are already defined in the database are allowed.
' The client of the subroutine must provider both the entry date and the transaction
' date, where the latter should always be equal to or less than the former. If the
' adjustment is a transfer, a known PIN is used as the TO_PIN. Otherwise
' the depot PIN is used.The vaccine and lot number provider must also
' exist in the database
'
' Arguments:
'           aDepotPIN - The pin of the depot to which the adjustment is being
'           reported. If the adjustment is a transfer, this field is ignored.
'
'           anEntryDate - The reporting date for the adjustment
'
'           aTransactionDate - The date the adjustment was made by the Provider
'
'           aTransactionType - The type of adjustment being reported
'
'           aPIN - The pin of the provider reporting the adjustment
'
'           aVaccine - The name of the vaccine being reported for adjustment
'
'           aLotNumber - The lot number of the vaccine being reported for adjustment
'
'           aDoseCount - The number of doses being reported for adjustment
'
' Exceptions:
'           VM_NULL_ENTRY_DATE
'           VM_NULL_TRANSACTION_DATE
'           VM_WRONG_ACTION_CODES
'           VM_UNKNOWN_ACTION_CODES
'
' CHANGE HISTORY
' Request Id  Date        Author          Description
' ------------------------------------------------------------------------
' R1352       11/05/2001  Stephen Nelson  ODBC 6.0 does not work with the
'                                         DateValue() function.  Replaced
'                                         with brackets {}.
' R1596       03/04/2002  Joe Bernard     ODBC 6.0 also does not work with
'                                         ltrim and rtrim on numeric or
'                                         date values. Removed these on
'                                         action and dateout fields.
' R1701       06/20/2002  Joe Bernard     Dixmont (Sub-Request R1624)
'                                         Modified to include new inventory
'                                         adjustment codes.
' R1812:D4358 09/17/2004  Stephen Nelson  Release Tulane
'                                         Modified the procedure to include
'                                         additional fields, which were
'                                         added to the DISTRIB table in
'                                         the release of Vacman 3.0.8.
'                                         Attempting to capture the same
'                                         type of information that is
'                                         captured through the Vacman
'                                         application front-end.
'             07/05/2007  Matt Martin     Added other/unusable transaction reason
'             08/14/2007  Matt Martin     Returned is a valid transaction reason
'#########################################################################
Public Sub providerInventoryAdjustmentUpdate( _
            ByVal aDepotPIN As String, _
            ByVal anEntryDate As String, _
            ByVal aTransactionDate As String, _
            ByVal aTransactionType As String, _
            ByVal aPIN As String, _
            ByVal aVaccine As String, _
            ByVal aLotNumber As String, _
            ByVal aDoseCount As Long)

On Error GoTo ErrorHandler

    App.LogEvent "Begin: providerInventoryAdjustmentUpdate()", vbLogEventTypeInformation
    Dim query As String
    Dim isPINValid As Boolean
    Dim toPIN As String
    Dim transactionCode As Long
    Dim rowCount As Long
    Dim recordCount As Long
    Dim doses As Long
    Dim vialSize As Long
    Dim numOfVials As Long
    ' R1812:D4358 Start Change
    Dim status As String
    Dim chgdate As Date
    Dim distID As Long
    Dim shipped As Long
    Dim notes As String

    notes = "Entered from ImmPact front-end."
    
    chgdate = Date
    ' R1812:D4358 End Change

    'To accomodate -ve adjustment
    If aDoseCount = 0 Then
        RaiseError VM_INVALID_ADJUSTMENT_DOSES_NUMBER, _
                    VM_INVALID_ADJUSTMENT_DOSES_MESSAGE
    End If

    aDepotPIN = UCase(aDepotPIN)
    anEntryDate = UCase(anEntryDate)
    aTransactionDate = UCase(aTransactionDate)

    aPIN = UCase(aPIN)
    aVaccine = UCase(aVaccine)
    aLotNumber = UCase(aLotNumber)

    aDoseCount = Abs(aDoseCount)

    If ValidateNullString(anEntryDate) = True Then
        RaiseError VM_NULL_ENTRY_DATE_NUMBER, _
                VM_NULL_ENTRY_DATE_MESSAGE
    End If

    If ValidateNullString(aTransactionDate) = True Then
        RaiseError VM_NULL_TRANSACTION_DATE_NUMBER, _
                VM_NULL_TRANSACTION_DATE_MESSAGE
    End If

    ValidateProviderInventoryAdjustDates anEntryDate, aTransactionDate

    If ValidateProviderPIN(aPIN, False, Connection) = False Then
                RaiseError VM_PROVIDER_PIN_NOT_FOUND_NUMBER, _
                    VM_PROVIDER_PIN_NOT_FOUND_MESSAGE
    End If

    ValidateDepotPIN aDepotPIN, Connection

    'To accomodate sending adjustment on the practice inventory which is not received from state
    'It is possible, the private received vaccine does not exist in vacman

    'ValidateAgainstpVaccRefTable aPIN, aVaccine, Connection

    ValidateVaccineLot aVaccine, aLotNumber, Connection

    ValidateActionCode aTransactionType, Connection

    transactionCode = AdjustmentCode(aTransactionType, Connection)

    'Need to make sure that only provider inventory adjustments go through
    'Also need to make sure that if adjustment is a transfer the pin toPIN
    'is not the depotPIN. We are putting NONE_STRING for now pending resolution
    'of whether to use a hard-coded pin or read a special one from the db

    'R1701 - Start modification
    If ((RETURNED <= transactionCode) And (REFRIGERATION >= transactionCode)) _
        Or LOST_UNACCOUNTED = transactionCode Or OTHER = transactionCode Then
        toPIN = aDepotPIN
    'R1701 - End
    ElseIf transactionCode = TRANSFER Then
        toPIN = NONE_STRING
    ElseIf (transactionCode = PROVIDER_ORDER) Or (transactionCode = TRANSMITTED) Then
        RaiseError VM_WRONG_ACTION_CODES_NUMBER, _
                VM_WRONG_ACTION_CODES_MESSAGE
    Else
        RaiseError VM_UNKNOWN_ACTION_CODES_NUMBER, _
                VM_UNKNOWN_ACTION_CODES_MESSAGE
    End If

    If True = ValidateDuplicateProviderInventoryAdjustment(aTransactionDate, _
                                                        transactionCode, _
                                                        toPIN, _
                                                        aPIN, _
                                                        aVaccine, _
                                                        aLotNumber, _
                                                        Connection) Then


        doses = TransactionDoses(transactionCode, aPIN, aVaccine, aLotNumber, aTransactionDate, toPIN, Connection)

        doses = doses + aDoseCount

        ' R1812:D4358 Start Change
        ' Associated with this change, removed
        ' the reporting of the vial size. This
        ' information was not captured by the
        ' Vacman application front-end, so it
        ' was determined not to be important.
        query = "UPDATE distrib "
        query = query & "SET doses  = " & doses & ", "
        query = query & "chgdate = {" & chgdate & "}, "
        query = query & "userid = '" & VACMAN_DLL_USER & "' "
        query = query & "WHERE action = " & transactionCode & " "  'R1596 Change
        query = query & "AND ltrim(rtrim(pin)) = '" & aPIN & "' "
        query = query & "AND ltrim(rtrim(vaccine)) = '" & aVaccine & "' "
        query = query & "AND ltrim(rtrim(strtran(lot,ltrim(rtrim('-')),''))) = '" & Replace(aLotNumber, "-", "") & "' "
        query = query & "AND dateout = {" & aTransactionDate & "} "  'R1596 Change
        query = query & "AND ltrim(rtrim(fromPIN)) = '" & toPIN & "'"
        Debug.Print query
        ' R1812:D4358 End Change

    Else
        ' R1812:D4358 Start Change
        ' Associated with this change, removed
        ' the reporting of the vial size. This
        ' information was not captured by the
        ' Vacman application front-end, so it
        ' was determined not to be important.
        distID = 0
        status = getDistribStatusCode(transactionCode)
        shipped = 0

        query = "INSERT INTO distrib (input, dateout, frompin, pin, vaccine, lot, doses, action, distid, notes, chgdate, status, shipped, userid) values"  '''units,
        query = query & " ( {" & anEntryDate & "}, "
        query = query & " {" & aTransactionDate & "}, '"
        query = query & toPIN & "', '"
        query = query & aPIN & "', '"
        query = query & aVaccine & "', '"
        query = query & aLotNumber & "', "
        query = query & aDoseCount & ", "
        query = query & transactionCode & ", "
        query = query & distID & ", '"
        query = query & notes & "', "
        query = query & " {" & chgdate & "}, '"
        query = query & status & "', "
        query = query & shipped & ", '"
        query = query & VACMAN_DLL_USER & "')"
        
        Debug.Print query
        ' R1812:D4358 End Change
    
    End If

    Connection.Execute query

    App.LogEvent "End: providerInventoryAdjustmentUpdate()", vbLogEventTypeInformation


Exit Sub

ErrorHandler:
    Debug.Print Err.source
    Debug.Print Err.Description
    Debug.Print Err.Number
    Debug.Print Err.HelpFile
    Debug.Print Err.HelpContext
    Dim desc As String
    Dim code As Long
    desc = Err.Description
    code = Err.Number

    App.LogEvent "Problem: In providerInventoryAdjustmentUpdate() " & desc, vbLogEventTypeError

    Err.Raise code, "VACMAN DLL", desc
End Sub

'#########################################################################
' Subroutine Name: providerShippingDataUpdate
'
' Description: Updates the shipping information for the given PIN.
' It is assumed that the PIN already exists in VACMAN.
'
' Arguments:
'           aPIN - The pin of the provider whose profile is being updated
'
'           aFacilityLastName - Last name of a private provider OR the
'           entire name of the facility.
'
'           aShippingContact - Person to contact for information or about
'           or questions about vaccine shipments or deliveries.
'
'           aShippingAddress1 - First line of the provider shipping address.
'
'           aShippingAddress2 - Second line of the provider shipping address.
'
'           aShippingCity - Shipping address city.
'
'           aShippingState - Shipping address state.
'
'           aShippingZipCode - Shiping address zip code.
'
'           aShippingInstructions - Shipping instructions.
'
'           aPhoneNumber - Provider phone number.
'
'           aFaxNumber - Provider fax number.
'
'           Optional aPhoneExtension - Extension to the provider phone number.
'
'           Optional aFirstName - First name of private provider.
'
'           Optional aMiddleInitial - Middle initial of private provider.
'
'           Optional aTitle - Title of private provider.
'
' Exceptions:
'           VM_NULL_PROVIDER_NAME
'           VM_NULL_SHIPPING_CONTACT
'           VM_INVALID_PHONE_NUMBER
'           VM_INVALID_FAX_NUMBER
'           VM_PIN_NOT_FOUND_FOR_SHIPPING_UPDATE
'
' CHANGE HISTORY
' Request Id  Date        Author          Description
' ------------------------------------------------------------------------
' R1352       11/05/2001  Stephen Nelson  ODBC 6.0 does not work with the
'                                         DateValue() function.  Replaced
'                                         with brackets {}.
'                                         Changed the reference to the note
'                                         field. No longer place it in double
'                                         quotes.
' R1812:D4358 09/30/2004  Stephen Nelson  Release Tulane
'                                         Added county name to the data
'                                         inserted or updated in the PROVIDER
'                                         table.
'#########################################################################
Public Sub providerShippingDataUpdate( _
            ByVal aPIN As String, _
            ByVal aFacilityLastName As String, _
            ByVal aShippingContact As String, _
            ByVal aShippingAddress1 As String, ByVal aShippingAddress2 As String, _
            ByVal aShippingCity As String, ByVal aShippingState As String, ByVal aShippingZipCode As String, _
            ByVal aShippingInstructions As String, _
            ByVal aPhoneNumber As String, _
            ByVal aFaxNumber As String, _
            Optional ByVal aPhoneExtension As Variant, _
            Optional ByVal aFirstName As Variant, _
            Optional ByVal aMiddleInitial As Variant, _
            Optional ByVal aTitle As Variant)
            
On Error GoTo ErrorHandler
    App.LogEvent "Begin: providerShippingDataUpdate()", vbLogEventTypeInformation

    Dim query As String
    Dim isPINValid As Boolean
    Dim setClause As String
    Dim currentDate As Date
    Dim countyName As String  ' R1812:D4358 Change
    
    currentDate = Date

    aPIN = UCase(aPIN)
    aFacilityLastName = UCase(aFacilityLastName)
    aShippingContact = UCase(aShippingContact)
    aShippingAddress1 = UCase(stripInvalidCharacters(aShippingAddress1))
    aShippingAddress2 = UCase(stripInvalidCharacters(aShippingAddress2))
    aShippingCity = UCase(stripInvalidCharacters(aShippingCity))
    aShippingState = UCase(stripInvalidCharacters(aShippingState))
    aShippingZipCode = UCase(stripInvalidCharacters(aShippingZipCode))
    aShippingInstructions = UCase(stripInvalidCharacters(aShippingInstructions))
    aPhoneNumber = UCase(aPhoneNumber)
    aFaxNumber = UCase(aFaxNumber)

    If IsMissing(aPhoneExtension) = False Then
        aPhoneExtension = UCase(aPhoneExtension)
    End If

    If IsMissing(aFirstName) = False Then
        aFirstName = UCase(aFirstName)
    End If
    If IsMissing(aMiddleInitial) = False Then
        aMiddleInitial = UCase(aMiddleInitial)
    End If

    If IsMissing(aTitle) = False Then
        aTitle = UCase(aTitle)
    End If


    isPINValid = ValidateProviderPIN(aPIN, True, Connection)
    If (isPINValid = False) Then
     RaiseError VM_PIN_NOT_FOUND_FOR_SHIPPING_UPDATE_NUMBER, _
                        VM_PIN_NOT_FOUND_FOR_SHIPPING_UPDATE_MESSAGE
    End If

    If ValidateNullString(aFacilityLastName) = True Then
            RaiseError VM_NULL_PROVIDER_NAME_NUMBER, _
                        VM_NULL_PROVIDER_NAME_MESSAGE
    End If

    If ValidateNullString(aShippingContact) = True Then
                RaiseError VM_NULL_SHIPPING_CONTACT_NUMBER, _
                        VM_NULL_SHIPPING_CONTACT_MESSAGE
    End If

    App.LogEvent "Before calling ValidateShippingAddress", vbLogEventTypeInformation

    ValidateShippingAddress aShippingAddress1, _
                        aShippingAddress2, _
                        aShippingCity, _
                        aShippingZipCode, _
                        aShippingState, _
                        Connection
    
    App.LogEvent "After calling ValidateShippingAddress", vbLogEventTypeInformation


    If ValidateNullString(aShippingInstructions) = True Then
            aShippingInstructions = NONE_STRING
    End If


    If ValidatePhoneFaxFormat(aPhoneNumber) = False Then
        RaiseError VM_INVALID_PHONE_NUMBER_NUMBER, _
                    VM_INVALID_PHONE_NUMBER_MESSAGE
    End If
    If ValidateNullString(aFaxNumber) = False Then
        If ValidatePhoneFaxFormat(aFaxNumber) = False Then
            RaiseError VM_INVALID_FAX_NUMBER_NUMBER, _
                        VM_INVALID_FAX_NUMBER_MESSAGE
        End If
    End If
         
    setClause = "SET "
    
    If IsMissing(aPhoneExtension) = False Then
        setClause = setClause & "extension = '" & CStr(aPhoneExtension) & "', "
    End If

    If IsMissing(aFirstName) = False Then
        setClause = setClause & "firstname = '" & CStr(aFirstName) & "', "
    End If

    If IsMissing(aMiddleInitial) = False Then
        setClause = setClause & "initial = '" & CStr(aMiddleInitial) & "', "
    End If

    If IsMissing(aTitle) = False Then
        setClause = setClause & "title = '" & CStr(aTitle) & "', "
    End If
    
    ' R1812:D4358 Start Change
    countyName = getCountyName(aShippingZipCode)
    
    If countyName <> vbNullString Then
        setClause = setClause & "county = '" & countyName & "', "  ' R1812:D4358 Change
    End If
    ' R1812:D4358 End Change
    
    'It is important that this is block of required
    'fields is at the end. Otherwise we would have
    'to keep track of where to put commas
    setClause = setClause & "contact = '" & aShippingContact & "', "
    setClause = setClause & "lastname = '" & aFacilityLastName & "', "
    setClause = setClause & "address = '" & aShippingAddress1 & "', "
    setClause = setClause & "addres2 = '" & aShippingAddress2 & "', "
    setClause = setClause & "city = '" & aShippingCity & "', "
    setClause = setClause & "state = '" & aShippingState & "', "
    setClause = setClause & "zipcode = '" & aShippingZipCode & "', "
    ''' R1272 setClause = setClause & """note"" = '" & aShippingInstructions & "', "
    setClause = setClause & "note = '" & aShippingInstructions & "', "
    setClause = setClause & "phone = '" & aPhoneNumber & "', "
    setClause = setClause & "fax = '" & aFaxNumber & "', "
    ''' R1272 setClause = setClause & "chgdate = datevalue('" & currentDate & "'), "
    setClause = setClause & "chgdate = {" & currentDate & "}, "
    setClause = setClause & "userid = '" & VACMAN_DLL_USER & "' "
    
    query = "UPDATE provider "
    query = query & setClause
    query = query & "WHERE ltrim(rtrim(pin)) = '" & aPIN & "'"
    App.LogEvent query, vbLogEventTypeInformation
    Connection.Execute query
    App.LogEvent "End: providerShippingDataUpdate()", vbLogEventTypeInformation

Exit Sub

ErrorHandler:
    Debug.Print Err.source
    Debug.Print Err.Description
    Debug.Print Err.Number
    Debug.Print Err.HelpFile
    Debug.Print Err.HelpContext
    Dim desc As String
    Dim code As Long
    desc = Err.Description
    code = Err.Number
    
    App.LogEvent "Problem: In providerShippingDataUpdate() " & desc, vbLogEventTypeError
    
    Err.Raise code, "VACMAN DLL", desc

    
End Sub




Private Sub Class_Terminate()
    App.LogEvent "Begin: Class_Terminate()", vbLogEventTypeInformation

   'Destroy connection object
   Set myConnection = Nothing
    App.LogEvent "End: Class_Terminate()", vbLogEventTypeInformation
End Sub

'#########################################################################
' Subroutine Name: DosesAdministeredUpdate
'
' Description:  Insert a new dose administration record or update
'               an existing one and update the
'
' Arguments:
'   aDepotPIN:          the Pin of the depot
'   aReportingDate      the reporting date
'   aPIN:               the Pin of the provider
'   aVaccine:           the vaccine name
'   aSector:            the sector of the provider
'   aDoseInSeries:      the dose series of the vaccine
'   Optional aDoseCountLessThanOne:             the dose admin for age < 1
'   Optional aDoseCountForOneYear:              the dose admin for 1 age <2
'   Optional aDoseCountForTwoYears:             the dose admin for 2 age <3
'   Optional aDoseCountForThreetoFourYears:     the dose admin for 3 age <5
'   Optional aDoseCountForFiveYears:            the dose admin for 5 age <6
'   Optional aDoseCountForSixtoNineYears:       the dose admin for 6 age <10
'   Optional aDoseCountForTentoFourteenYears:   the dose admin for 10 age <15
'   Optional aDoseCountForFifteentoNineteenYears:   the dose admin for 15 age <20
'   Optional aDoseCountForTwentytoTwentyFourYears:  the dose admin for 20 age <25
'   Optional aDoseCountForTwentyFivetoFourtyFourYears:  the dose admin for 25 age <44
'   Optional aDoseCountForFourtyFivetoSixtyFourYears:   the dose admin for 45 age <65
'   Optional aDoseCountForGreaterThanSixtyFiveYears:    the dose admin for age >65
'   Optional anUnknown:                     the dose admin for unknown age
'   Optional aTotalDoses:                   the total dose admin
'   Optional aUserDefinedCategory1:         for future use
'   Optional aUserDefinedCategory2:         for future use
'   Optional aUserDefinedCategory3:         for future use
'''Begin Change R1812:D4358
'   Optional aUserDefinedCategory4:         for future use
'   Optional aUserDefinedCategory5:         for future use
'   Optional aUserDefinedCategory6:         for future use
'   Optional aUserDefinedCategory7:         for future use
'   Optional aUserDefinedCategory8:         for future use
'   Optional aUserDefinedCategorytot: total for user defined fields
'   Optional VaccineCodingSheme - Either "VACMAN" or "HL7".
' Exceptions:
'
' CHANGE HISTORY
' Request Id  Date        Author          Description
' ------------------------------------------------------------------------
' R1352       11/05/2001  Stephen Nelson  ODBC 6.0 does not work with the
'                                         DateValue() function.  Replaced
'                                         with brackets {}.
'                                         Sector is a number. Removed the
'                                         trim statements from the query.
' R1596       03/04/2002  Joe Bernard     ODBC 6.0 also does not work with
'                                         ltrim and rtrim on numeric or
'                                         date values. Removed these on dose
'                                         and adate fields. Also corrected
'                                         problem with single quotes for
'                                         values compared or assigned to
'                                         the dose and sector fields.
'R1812:D4358  09/16/2004  Santosh Dominic Release Tulane
'                                         Make the changes for dll to be compatible
'                                         with version of Vacman 3.08 database.
'                                         This involved changes to the parameters
'                                         in DoseAdministeredUpdate subroutine.
'                                         Making changes to the insert an update
'                                         sql's.Adding the code to get the HL7 code
'                                         from the vaccine ref table if the
'                                         aVaccineCodingSheme is HL7.
'                                         Remove the begining and trailing space for
'                                         PIN.
' IMMPACT-529 06/12/2007  Mark Fleming    Change call to ValidateAgainstVaccRefTable
'                                         to exclude Pin
' IMMPACT-637 07/09/2007  Matt Martin     Fix broken update statement
' IMMPACT-1059 03/17/2008 Matt Martin     Include MMR-V in DOSA updates, its in the
'                                         vaccref table, which has completely different
'                                         active vaccines and max dose #s than the
'                                         pvaccref table, so I made a if test specifically
'                                         for MMR-V so we can validate against the appropriate table
'#########################################################################
Public Sub DosesAdministeredUpdate( _
                                    ByVal aReportingDate As String, _
                                    ByVal aPIN As String, _
                                    ByVal aVaccine As String, _
                                    ByVal aDoseInSeries As String, _
                                    Optional ByVal aSector As String = "1", _
                                    Optional ByVal aDoseCountLessThanOne As Long = 0, _
                                    Optional ByVal aDoseCountForOneYear As Long = 0, _
                                    Optional ByVal aDoseCountForTwoYears As Long = 0, _
                                    Optional ByVal aDoseCountForThreetoFourYears As Long = 0, _
                                    Optional ByVal aDoseCountForFiveYears As Long = 0, _
                                    Optional ByVal aDoseCountForSixtoNineYears As Long = 0, _
                                    Optional ByVal aDoseCountForTentoFourteenYears As Long = 0, _
                                    Optional ByVal aDoseCountForFifteentoNineteenYears As Long = 0, _
                                    Optional ByVal aDoseCountForTwentytoTwentyFourYears As Long = 0, _
                                    Optional ByVal aDoseCountForTwentyFivetoFourtyFourYears As Long = 0, _
                                    Optional ByVal aDoseCountForFourtyFivetoSixtyFourYears As Long = 0, _
                                    Optional ByVal aDoseCountForGreaterThanSixtyFiveYears As Long = 0, _
                                    Optional ByVal anUnknown As Long = 0, _
                                    Optional ByVal aTotalDoses As Long = 0, _
                                    Optional ByVal aUserDefinedCategory1 As Long = 0, _
                                    Optional ByVal aUserDefinedCategory2 As Long = 0, _
                                    Optional ByVal aUserDefinedCategory3 As Long = 0)
On Error GoTo ErrorHandler
    App.LogEvent "Begin: DosesAdministeredUpdate()", vbLogEventTypeInformation
    Dim query As String
    Dim recordset As ADODB.recordset
    ' R1812:D4358 Start Change
    Dim rowCount As Long
    Dim aDoseAdminId As Long
    
    Dim aUserDefinedCategory4 As Long
    Dim aUserDefinedCategory5 As Long
    Dim aUserDefinedCategory6 As Long
    Dim aUserDefinedCategory7 As Long
    Dim aUserDefinedCategory8 As Long
    Dim aUserDefinedCategorytot As Long

    Const c_POSITION As Long = 0   ' 0 - old age range; 1 - new age range
    
    aUserDefinedCategory4 = 0
    aUserDefinedCategory5 = 0
    aUserDefinedCategory6 = 0
    aUserDefinedCategory7 = 0
    aUserDefinedCategory8 = 0
    ' R1812:D4358 End Change

    Set recordset = CreateObject("ADODB.Recordset")
    
    aReportingDate = UCase(aReportingDate)
    aPIN = UCase(aPIN)
    aVaccine = UCase(aVaccine)
    aDoseInSeries = UCase(aDoseInSeries)
    
    If ValidateNullString(aReportingDate) = True Then
        RaiseError VM_NULL_REPORT_DATE_NUMBER, _
                    VM_NULL_REPORT_DATE_MESSAGE
    End If
    
    If ValidateNullString(aVaccine) = True Then
        RaiseError VM_NULL_VACCINE_NAME_NUMBER, _
                    VM_NULL_VACCINE_NAME_MESSAGE
    End If
    
    If ValidateNullString(aPIN) = True Then
        RaiseError VM_NULL_PROVIDER_PIN_NUMBER, _
                    VM_NULL_PROVIDER_PIN_NUMBER
    End If
    
    ValidateVaccAdminSector aSector
    
    ' MPF - 4/25/2007 Comment out call to allow for future dates
    'ValidateVaccAdminDate aReportingDate
    
    ValidateTotalDoses aDoseCountLessThanOne, aDoseCountForOneYear, aDoseCountForTwoYears, _
        aDoseCountForThreetoFourYears, aDoseCountForFiveYears, aDoseCountForSixtoNineYears, _
        aDoseCountForTentoFourteenYears, aDoseCountForFifteentoNineteenYears, aDoseCountForTwentytoTwentyFourYears, _
        aDoseCountForTwentyFivetoFourtyFourYears, aDoseCountForFourtyFivetoSixtyFourYears, _
        aDoseCountForGreaterThanSixtyFiveYears, anUnknown, aTotalDoses
                
    aUserDefinedCategorytot = aUserDefinedCategory1 + aUserDefinedCategory2 + aUserDefinedCategory3
    
    If ValidateProviderPIN(aPIN, False, Connection) = False Then
                RaiseError VM_PROVIDER_PIN_NOT_FOUND_NUMBER, _
                    VM_PROVIDER_PIN_NOT_FOUND_MESSAGE
    End If
    
    If (StrComp(aVaccine, "MMR-V") = 0) Then
        ValidateAgainstVaccRefTable aVaccine, Connection, False
    
        ValidateDoseSeriesNumber aDoseInSeries, aVaccine, Connection
    Else
        ValidateAgainstpVaccRefTable aVaccine, Connection, False
        ValidateDoseSeriesNumberPvaccref aDoseInSeries, aVaccine, Connection
    End If
    
    'Get NextId for DoseAdminId
     aDoseAdminId = getNextID("Dosesadm")  'R1812:D4358 Change
    
    If ValidateDuplicateDosesAdmin(aReportingDate, aPIN, aVaccine, aDoseInSeries, aSector, _
                   Connection) = False Then
        
        query = "INSERT INTO DosesAdm (adate, pin, sector, vaccine, position, dose, "
        query = query & "g1, g2, g3, g4, g5, g6, g7, g8, g9, g10, g11, g12, g13, rowtot, "
        query = query & "dauzr1, dauzr2, dauzr3, dauzr4, dauzr5, dauzr6, dauzr7, dauzr8, dauzrtot, "
        query = query & "chgdate, userid, dosesadmid) "
        query = query & "VALUES ( "
        query = query & "{" & aReportingDate & "}, "
        query = query & "'" & aPIN & "', "
        query = query & aSector & ", "
        query = query & "'" & aVaccine & "', "
        query = query & c_POSITION & ", "
        query = query & aDoseInSeries & ", "
        query = query & aDoseCountLessThanOne & ", "
        query = query & aDoseCountForOneYear & ", "
        query = query & aDoseCountForTwoYears & ", "
        query = query & aDoseCountForThreetoFourYears & ", "
        query = query & aDoseCountForFiveYears & ", "
        query = query & aDoseCountForSixtoNineYears & ", "
        query = query & aDoseCountForTentoFourteenYears & ", "
        query = query & aDoseCountForFifteentoNineteenYears & ", "
        query = query & aDoseCountForTwentytoTwentyFourYears & ", "
        query = query & aDoseCountForTwentyFivetoFourtyFourYears & ", "
        query = query & aDoseCountForFourtyFivetoSixtyFourYears & ", "
        query = query & aDoseCountForGreaterThanSixtyFiveYears & ", "
        query = query & anUnknown & ", "
        query = query & aTotalDoses & ", "
        query = query & aUserDefinedCategory1 & ", "
        query = query & aUserDefinedCategory2 & ", "
        query = query & aUserDefinedCategory3 & ", "
        query = query & aUserDefinedCategory4 & ", "
        query = query & aUserDefinedCategory5 & ", "
        query = query & aUserDefinedCategory6 & ", "
        query = query & aUserDefinedCategory7 & ", "
        query = query & aUserDefinedCategory8 & ", "
        query = query & aUserDefinedCategorytot & ", "
        query = query & "{" & Date & "}, "
        query = query & "'" & VACMAN_DLL_USER & "', "
        query = query & aDoseAdminId
        query = query & ")"
        Debug.Print query
    Else
        'Preparing Query for update

        query = "UPDATE DosesAdm "
        query = query & " SET g1=" & aDoseCountLessThanOne & ", "
        query = query & " g2=" & aDoseCountForOneYear & ", "
        query = query & " g3=" & aDoseCountForTwoYears & ", "
        query = query & " g4=" & aDoseCountForThreetoFourYears & ", "
        query = query & " g5=" & aDoseCountForFiveYears & ", "
        query = query & " g6=" & aDoseCountForSixtoNineYears & ", "
        query = query & " g7=" & aDoseCountForTentoFourteenYears & ", "
        query = query & " g8=" & aDoseCountForFifteentoNineteenYears & ", "
        query = query & " g9=" & aDoseCountForTwentytoTwentyFourYears & ", "
        query = query & " g10=" & aDoseCountForTwentyFivetoFourtyFourYears & ", "
        query = query & " g11=" & aDoseCountForFourtyFivetoSixtyFourYears & ", "
        query = query & " g12=" & aDoseCountForGreaterThanSixtyFiveYears & ", "
        query = query & " g13=" & anUnknown & ", "
        query = query & " RowTot=" & aTotalDoses & ", "
        query = query & " dauzr1=" & aUserDefinedCategory1 & ", "
        query = query & " dauzr2=" & aUserDefinedCategory2 & ", "
        query = query & " dauzr3=" & aUserDefinedCategory3 & ", "
        query = query & " dauzr4=" & aUserDefinedCategory4 & ", "
        query = query & " dauzr5=" & aUserDefinedCategory5 & ", "
        query = query & " dauzr6=" & aUserDefinedCategory6 & ", "
        query = query & " dauzr7=" & aUserDefinedCategory7 & ", "
        query = query & " dauzr8=" & aUserDefinedCategory8 & ", "
        query = query & " dauzrTot=" & aUserDefinedCategorytot & ", "
        query = query & " chgdate = {" & Date & "}, "
        query = query & " userid = '" & VACMAN_DLL_USER & "' "
        query = query & " WHERE  Pin = '" & aPIN & "' "
        query = query & " AND    ltrim(rtrim(vaccine))='" & aVaccine & "' "
        query = query & " AND    Dose = " & aDoseInSeries & " "
        query = query & " AND    sector = " & aSector & " "
        query = query & " AND    aDate = {" & aReportingDate & "} "
        Debug.Print query
        
    End If
    
    'Execute the insert/update query
    
    recordset.Open query, Connection, adOpenKeyset, adLockReadOnly, adCmdText
    Set recordset = Nothing
    App.LogEvent "End: DosesAdministeredUpdate()", vbLogEventTypeInformation

    Exit Sub
ErrorHandler:
    With recordset
        If .state = adStateOpen Then
            .Close
        End If
    End With
    Set recordset = Nothing
    Debug.Print Err.Number
    Debug.Print Err.Description
    Debug.Print Err.source
    Dim desc As String
    Dim code As Long
    desc = Err.Description
    code = Err.Number
    
    App.LogEvent "Problem: In DosesAdministeredUpdate() " & desc, vbLogEventTypeError
    
    Err.Raise code, "VACMAN DLL", desc
End Sub

'#########################################################################
' Subroutine Name: DepotProviderOrderUpdate
'
' Description:  A new order is inserted into the database and the State
'               inventory is decremented accordingly.  An existing order,
'               one with the same shipment date, depot id, pin, vaccine,
'               and lot number, is updated by adding additional doses
'               to the original order.  Again, the State inventory is
'               decremented by the doses shipped.
'
'               If the dose count is not a multiple of the vial size,
'               round up to the next multiple of the vial size.
'
' Parameters:
'               aShipmentDate:          the date of shipment
'               aDepotID:               the PIN of the depot
'               aPIN:                   the PIN of the provider
'               aVaccine:               the vaccine name
'               aDoseCount:             the dose count of the vaccine
'               aLotNumber:             the lot number of the vaccine
'               Optional anExcessAllow:
'               Optional anOrderDate:   the order date of the vaccine
'
' Exceptions:
'
' CHANGE HISTORY
' Request Id  Date        Author          Description
' ------------------------------------------------------------------------
' R1352       11/05/2001  Stephen Nelson  ODBC 6.0 does not work with the
'                                         DateValue() function.  Replaced
'                                         with brackets {}.
' R1812:D4358 09/20/2004 Santosh Dominic  Release Tulane: Removed the
'                                         leading spaces inserted into
'                                         vacman database with the PIN
'                                         column.  Added the new columns
'                                         associated with vacman 3.08 to
'                                         the insert and update statement.
' IMMPACT-529 06/12/2007  Mark Fleming    Change call to ValidateAgainstVaccRefTable
'                                         to exclude Pin
'             06/28/2007  Mark Fleming    Comment out query of lots table and calls
'                                         to getVialSize, ValidateAvailableInventoryLot,
'                                         and ValidateNumberofDoses, since state
'                                         inventory is no longer maintained.
'#########################################################################
Public Sub DepotProviderOrderUpdate( _
            ByVal aShipmentDate As String, _
            ByVal aDepotID As String, _
            ByVal aPIN As String, _
            ByVal aVaccine As String, _
            ByVal aDoseCount As Long, _
            ByVal aLotNumber As String, _
            Optional ByVal anExcessAllow As String = EXCESS_ALLOW_DEFAULT, _
            Optional ByVal anOrderDate As String)
            
On Error GoTo ErrorHandler
    App.LogEvent "Begin: DepotProviderOrderUpdate()", vbLogEventTypeInformation

    Dim recordset As ADODB.recordset
    Dim query As String
    Dim rowCount As Long
    
    Dim isPINValid As Boolean
    
    Dim decrementQty As Long
    Dim excessAllow As String
    Dim remainQty As Long
    
    Dim orderDate As String
    Dim action As Long
    Dim vialSize As Long
    Dim numOfVials As Long
    Dim newQty As Long
    
    Dim fdose1 As Long
    Dim fdose2 As Long
    Dim fdose3 As Long
    
    Dim seekid As Long
    Dim shipped As Long
    Dim status As String
    Dim chgdate As Date
    Dim distID As Long
    
    ' Change parameter values to upper case
    aShipmentDate = UCase(aShipmentDate)
    aDepotID = UCase(aDepotID)
    aPIN = UCase(aPIN)
    aLotNumber = UCase(aLotNumber)
    aVaccine = UCase(aVaccine)
    
    ' Initialize data values
    action = SHIPPING_ACTION_CODE
    chgdate = Date
    
    ' Check for the existance of optional parameters
    If ValidateNullString(anExcessAllow) = True Then
        anExcessAllow = EXCESS_ALLOW_DEFAULT
    End If
    
    If ValidateNullString(aShipmentDate) = True Then
        RaiseError VM_NULL_SHIPMENT_DATE_NUMBER, _
                    VM_NULL_SHIPMENT_DATE_MESSAGE
    End If
        
    If ValidateNullString(aDepotID) = True Then
        RaiseError VM_NULL_DEPOT_PIN_NUMBER, _
                    VM_NULL_DEPOT_PIN_MESSAGE
    End If
    
    If ValidateNullString(aPIN) = True Then
        RaiseError VM_NULL_PROVIDER_PIN_NUMBER, _
                    VM_NULL_PROVIDER_PIN_NUMBER
    End If
    
    If ValidateNullString(aVaccine) = True Then
        RaiseError VM_NULL_VACCINE_NAME_NUMBER, _
                    VM_NULL_VACCINE_NAME_MESSAGE
    End If
    
    If ValidateNullString(aLotNumber) = True Then
        RaiseError VM_NULL_LOTNUMBER_NUMBER, _
                    VM_NULL_LOTNUMBER_MESSAGE
    End If
    
    If aDoseCount <= 0 Then
         RaiseError VM_NULL_DOSE_NUMBER, _
                    VM_NULL_DOSE_MESSAGE
    End If
    
    If ValidateNullString(anOrderDate) = True Then
        orderDate = aShipmentDate
    Else
        orderDate = anOrderDate
    End If
    
    excessAllow = anExcessAllow
    
    ValidateExcessAllowance anExcessAllow

    
    
    Dim returnContract As Contract
    
    Set recordset = CreateObject("ADODB.Recordset")
    
    query = "SELECT * FROM pvaccref "
    query = query & "WHERE ltrim(rtrim(vaccine)) = '" & aVaccine & "' "
    If StrComp(aVaccine, "MCV4") = 0 Then
        query = query & "AND pkgsize=5"
    Else
        query = query & "AND pkgsize=10"
    End If
    
    Debug.Print query
    
    recordset.Open query, Connection, adOpenKeyset, adLockReadOnly, adCmdText
    rowCount = recordset.recordCount
    
    If (rowCount > 0) Then
        ' If there are more than one, use the first record.
        With returnContract
            .vaccine = Trim(recordset.Fields.Item(0))
            .maker = Trim(recordset.Fields.Item(1))
            .begin = recordset.Fields.Item(2)
            .end = recordset.Fields.Item(3)
            .minbulk = recordset.Fields.Item(4)
            .unitsize = recordset.Fields.Item(5)
            .pkgsize = recordset.Fields.Item(6)
            .ndcno = Trim(recordset.Fields.Item(7))
            .cost = recordset.Fields.Item(8)
            .contractid = Trim(recordset.Fields.Item(9))
            .sel_maker = Trim(recordset.Fields.Item(10))
            .dos_wind = Trim(recordset.Fields.Item(11))
            .excfunds = Trim(recordset.Fields.Item(12))
            .descrip = Trim(recordset.Fields.Item(13))
        End With
    Else
        RaiseError VM_CONTRACT_TABLE_ERROR_NUMBER, _
           VM_CONTRACT_TABLE_ERROR_MESSAGE
    End If
    
    CloseRecordSet recordset
    Set recordset = Nothing
    
    
    
    ' Initialize the recordset to receive query results.
    Set recordset = CreateObject("ADODB.Recordset")
    
    If ValidateDuplicateDepotProviderOrder( _
                    orderDate, aShipmentDate, aDepotID, _
                    aPIN, aVaccine, aLotNumber, Connection) = True Then
        'There is an existing order
        
        'Get the ordered dose count of the existing order
        query = "SELECT doses FROM distrib "
        query = query & "WHERE  ltrim(rtrim(FromPin)) = '" & aDepotID & "' "
        query = query & "AND    ltrim(rtrim(pin)) ='" & aPIN & "' "
        query = query & "AND    ltrim(rtrim(vaccine))='" & aVaccine & "' "
        query = query & "AND    ltrim(rtrim(strtran(lot,ltrim(rtrim('-')),'')))='" & Replace(aLotNumber, "-", "") & "' "
        query = query & "AND    dateout={" & aShipmentDate & "} "  'R1272 Change
        query = query & "AND    action=" & SHIPPING_ACTION_CODE
        Debug.Print query
    
        recordset.Open query, Connection, adOpenKeyset, adLockReadOnly, adCmdText
        rowCount = recordset.recordCount
        Debug.Print rowCount
        
        If rowCount <> 1 Then
            RaiseError VM_DUPLICATE_DEPOT_ORDER_ERROR_NUMBER, _
                        VM_DUPLICATE_DEPOT_ORDER_ERROR_MESSAGE
        End If
        
        If IsNull(recordset.Fields.Item(0)) = False Then
            newQty = recordset.Fields.Item(0)
        Else
            newQty = 0
        End If
        
        decrementQty = newQty
        
        ' Set the quantity (newQty) for the updated record in the DISTRIB table, and
        newQty = newQty + aDoseCount
        CloseRecordSet recordset
        
        ' MF - comment out code
        'ValidateNumberofDoses aDepotID, aVaccine, aLotNumber, newQty, Connection
        
        'Set decrementQty to the quantity to be reduced from the state inventory
        'decrementQty = newQty - decrementQty
        
'''        ' ****** What is the purpose of this procedure call at this point?
'''        CloseRecordSet recordset

        ' Check to ensure the doses are available in the LOTS table
        'ValidateAvailableInventoryLot aDepotID, aVaccine, aLotNumber, decrementQty, Connection
                        
        'vialSize = getVialSize(aVaccine, aLotNumber, Connection)
        'If (vialSize > 0) Then
        '   numOfVials = newQty / vialSize
        'Else
        '    numOfVials = 0
        'End If
        
        fdose1 = newQty
        
        'Prepare Query for update
        query = "UPDATE distrib SET doses = " & newQty & ", "
        query = query & "units = " & numOfVials & ", "
        query = query & "fdose1 = " & fdose1 & ", "
        query = query & "chgdate = {" & Date & "}, "
        query = query & "userid = '" & VACMAN_DLL_USER & "' "
        query = query & "WHERE  ltrim(rtrim(FromPin)) = '" & aDepotID & "' "
        query = query & "AND    ltrim(rtrim(pin)) = '" & aPIN & "' "
        query = query & "AND    ltrim(rtrim(vaccine))= '" & aVaccine & "' "
        query = query & "AND    ltrim(rtrim(strtran(lot,ltrim(rtrim('-')),'')))= '" & Replace(aLotNumber, "-", "") & "' "
        query = query & "AND    dateout= {" & aShipmentDate & "} "  'R1272 Change
        query = query & "AND    action= " & SHIPPING_ACTION_CODE
        Debug.Print query
    Else
        
        'There is no existing order
        newQty = aDoseCount
                
        ' MPF - 04/25/2007 Comment out two calls to allow for future dates
        'ValidateOrderDate orderDate
        
        'ValidateShipmentDate orderDate, aShipmentDate

        ValidateDepotPIN aDepotID, Connection
        
        If ValidateProviderPIN(aPIN, True, Connection) = False Then
                RaiseError VM_PROVIDER_PIN_NOT_FOUND_NUMBER, _
                            VM_PROVIDER_PIN_NOT_FOUND_MESSAGE
        End If
        
        ' MF - comment out code
        'vialSize = getVialSize(aVaccine, aLotNumber, Connection)
        
        'If (vialSize > 0) Then
        '    numOfVials = aDoseCount / vialSize
        'Else
        '    numOfVials = 0
        'End If
        
        ValidateAgainstpVaccRefTable aVaccine, Connection
        
        'ValidateNumberofDoses aDepotID, aVaccine, aLotNumber, newQty, Connection
        
        'ValidateAvailableInventoryLot aDepotID, aVaccine, aLotNumber, newQty, Connection
        
        'decrementQty is the qty to be deducted from the state inventory
        'decrementQty = newQty
                
        'Begin Change R1812:D4358
        
        'Get the distId and seekid from the NEXTID table
        distID = getNextID("distrib")
        seekid = getNextID("seekdist")
        
        fdose1 = newQty
        
        shipped = 1
        
        status = getDistribStatusCode(action)
        
        'Remove the Leading Space
        aPIN = Trim(aPIN)
        'End Change R1812:D4358
                
        'Preparing Query for insert
        ' R1812:D4358 Begin Change
        'query = "INSERT INTO distrib (input, dateout, pin, frompin, action, lot, "
        'query = query & "vaccine, units, doses, fdose1, fdose2 ,fdose3, seekid, status, "
        'query = query & "chgdate, userid, distid) VALUES"
        ' R1272 Start Change
        'query = query & " ( {" & orderDate & "}, "     ' input
        'query = query & " {" & aShipmentDate & "}, "   ' dateout
        ' R1272 End Change
        'query = query & "'" & aPIN & "', "             ' pin
        'query = query & "'" & aDepotID & "', "         ' frompin
        'query = query & action & ", "                  ' action
        'query = query & "'" & aLotNumber & "', "       ' lot
        'query = query & "'" & aVaccine & "', "         ' vaccine
        'query = query & numOfVials & ", "              ' units
        'query = query & newQty & ", "                  ' doses
        'query = query & fdose1 & ", "                  ' fdose1
        'query = query & fdose2 & ", "                  ' fdose2
        'query = query & fdose3 & ", "                  ' fdose3
        'query = query & seekid & ", "                  ' seekid
        'query = query & "'" & status & "', "           ' status
        'query = query & "{" & chgdate & "}, "          ' chgdate
        'query = query & "'" & VACMAN_DLL_USER & "', "  ' userid
        'query = query & distID & ") "                  ' distid
        ' R1812:D4358 End Change
        query = "INSERT INTO neworder(rectype, pin, orddate, orddose, size, vaccine, "
        query = query & "maker, cost, contract, fcode1, fdose1, chgdate, userid, "
        query = query & "ndcno, descrip) VALUES"
        query = query & "('5', "                                ' rectype = 5 (non-VAR)
        query = query & "'" & aPIN & "', "                      ' pin = site pin
        query = query & " {" & aShipmentDate & "}, "            ' orddate = order date
        query = query & aDoseCount & ", "                       ' orddose = doses
        query = query & returnContract.pkgsize & ", "           ' size = package dose multiples
        query = query & "'" & aVaccine & "', "                  ' vaccine = pvaccref
        query = query & "'" & returnContract.maker & "', "      ' maker = pvaccref
        query = query & returnContract.cost & ", "              ' cost = pvaccref
        query = query & "'" & returnContract.contractid & "', " ' contract = pvaccref
        query = query & "'1', "                                 ' funding code = 1
        query = query & aDoseCount & ", "                       ' fdose1 = doses
        query = query & " {" & aShipmentDate & "}, "            ' chgdate = order date
        query = query & "'" & VACMAN_DLL_USER & "', "           ' userid = vac_dll
        query = query & "'" & returnContract.ndcno & "', "      ' ndcno = pvaccref
        query = query & "'" & returnContract.descrip & "') "    ' descrip = pvaccref
        App.LogEvent query, vbLogEventTypeInformation
        Debug.Print query
    
    End If
    
    'Execute the Query
    
    recordset.Open query, Connection, adOpenKeyset, adLockReadOnly, adCmdText
    
    'get the inventory count of the state inventory
    
    'query = "SELECT remain from lots "
    'query = query & "WHERE ltrim(rtrim(pin)) = '" & aDepotID & "' "
    'query = query & "AND ltrim(rtrim(vaccine)) = '" & aVaccine & "' "
    'query = query & "AND ltrim(rtrim(lot)) = '" & aLotNumber & "' "
    
    'Debug.Print query
    'recordset.Open query, Connection, adOpenKeyset, adLockReadOnly, adCmdText
    'rowCount = recordset.recordCount
    'Debug.Print rowCount
    
    'If rowCount < 1 Then
    '     RaiseError VM_AVAIL_INVENTORY_LOT_COUNT_ERROR_NUMBER, _
    '                VM_AVAIL_INVENTORY_LOT_COUNT_ERROR_MESSAGE
    'End If
    'If IsNull(recordset.Fields.Item(0)) = False Then
    '    newQty = recordset.Fields.Item(0)
    'Else
    '    newQty = 0
    'End If
    
    'Debug.Print newQty
        
    'newQty = newQty - decrementQty
    'If newQty < 0 Then
    '    RaiseError VM_NOT_ENOUGH_STOCK_NUMBER, _
    '                VM_NOT_ENOUGH_STOCK_MESSAGE
    'End If
    'CloseRecordSet recordset
    
    'If (vialSize > 0) Then
    '    numOfVials = newQty / vialSize
    'Else
    '    numOfVials = 0
    'End If
        
    'Prepare Update query for state inventory update
    
    'query = "UPDATE lots SET remain= " & newQty & ", "
    'query = query & "units= " & numOfVials & " "
    'query = query & "WHERE  ltrim(rtrim(Pin)) = '" & aDepotID & "' "
    'query = query & "AND    ltrim(rtrim(vaccine))='" & aVaccine & "' "
    'query = query & "AND    ltrim(rtrim(Lot))='" & aLotNumber & "' "
    'Debug.Print query
                
    'Execute the update to the state inventory
    
    'recordset.Open query, Connection, adOpenKeyset, adLockReadOnly, adCmdText
    Set recordset = Nothing
    App.LogEvent "End: DepotProviderOrderUpdate()", vbLogEventTypeInformation

    Exit Sub
ErrorHandler:
    With recordset
        If .state = adStateOpen Then
            .Close
        End If
    End With
    Set recordset = Nothing
    Debug.Print Err.Number
    Debug.Print Err.Description
    Debug.Print Err.source
    Dim desc As String
    Dim code As Long
    desc = Err.Description
    code = Err.Number
    
    App.LogEvent "Problem: In DepotProviderOrderUpdate() " & desc, vbLogEventTypeError
    
    Err.Raise code, "VACMAN DLL", desc
End Sub

'#########################################################################
' Subroutine Name: providerEnrollmentAddUpdate
'
' Description: Creates or updates a record in the enroll table.  aAgegroup field will
'              determine which fields are updated.  For example; aAgegroup = 1 will
'              update Allkids1, Medicaid1, Uninsured1, etc.
'
'
' Arguments:
'           aPIN:           The pin of the provider whose profile is being updated
'           aSource:        The source of the data
'           aAgeGroup:      The age group of the individual
'           aAll:           Total number of children receiving immunization
'           aMedicaid:      Number of children qualifying for medicaid
'           aUninsured:     Number of children uninsured for health care
'           aAmIndian:      Number of American Indian and Alaskan Native children
'           aFQHC_RHC:      Number of children underinsured and are served in a
'                           Federally Qualified Health Center or Rural Health Center
'           aVFC:           Number of children who are VFC eligible (should equal total
'                           of previous 4 fields)
'           aG317:          Number of children not VFC eligible but eligible for free
'                           vaccines through G317 funds.
'           aState:         Number of children not VFC eligible but eligible for free
'                           vaccines through State/other funds.
'
' Exceptions:
'
' CHANGE HISTORY
' Request Id  Date        Author          Description
' ------------------------------------------------------------------------
' IMMPACT-200 01/25/2007  Mark Fleming    Function Created
' IMMPACT-625 07/03/2007  Matt Martin     Update userid with VAC_DLL user
'#########################################################################
Public Sub providerEnrollmentAddUpdate(ByVal aPIN As String, _
                                       ByVal aSource As String, _
                                       ByVal aAgeGroup As String, _
                                       ByVal aAll As String, _
                                       ByVal aMedicaid As String, _
                                       ByVal aUninsured As String, _
                                       ByVal aAmIndian As String, _
                                       ByVal aFQHC_RHC As String, _
                                       ByVal aVFC As String, _
                                       ByVal aG317 As String, _
                                       ByVal aState As String)

On Error GoTo ErrorHandler
    App.LogEvent "Begin: providerEnrollmentAddUpdate()", vbLogEventTypeInformation

    Dim recordset As ADODB.recordset
    Dim query As String
    Dim rowCount As Long
    Dim age_group As Integer
    Dim all, medicaid, uninsured, amindian, fqhc_rhc, vfc, g317, state As Long
    Dim source As String
    Dim chgdate As Date
    Dim msg As String
        
    chgdate = Date
    
     ' Initialize the recordset to receive query results.
    Set recordset = CreateObject("ADODB.Recordset")
    
    ' Change parameter values to upper case
    aPIN = UCase(aPIN)
    aSource = UCase(aSource)
    aAgeGroup = UCase(aAgeGroup)
    aAll = UCase(aAll)
    aMedicaid = UCase(aMedicaid)
    aUninsured = UCase(aUninsured)
    aAmIndian = UCase(aAmIndian)
    aFQHC_RHC = UCase(aFQHC_RHC)
    aVFC = UCase(aVFC)
    aG317 = UCase(aG317)
    aState = UCase(aState)
    
    If ValidateNullString(aPIN) = True Then
        RaiseError VM_NULL_ENROLL_PIN_NUMBER, _
                    VM_NULL_ENROLL_PIN_MESSAGE
    End If
    
    If ValidateNullString(aSource) = True Then
        RaiseError VM_NULL_ENROLL_SOURCE_NUMBER, _
                    VM_NULL_ENROLL_SOURCE_MESSAGE
    End If
    
    If ValidateNullString(aAgeGroup) = True Then
        RaiseError VM_NULL_ENROLL_AGE_GROUP_NUMBER, _
                    VM_NULL_ENROLL_AGE_GROUP_MESSAGE
    End If
    
    If ValidateNullString(aAll) = True Then
        RaiseError VM_NULL_ENROLL_ALL_KIDS_NUMBER, _
                    VM_NULL_ENROLL_ALL_KIDS_MESSAGE
    End If
    
    If ValidateNullString(aMedicaid) = True Then
        RaiseError VM_NULL_ENROLL_MEDICAID_NUMBER, _
                    VM_NULL_ENROLL_MEDICAID_MESSAGE
    End If
    
    If ValidateNullString(aUninsured) = True Then
        RaiseError VM_NULL_ENROLL_UNINSURED_NUMBER, _
                    VM_NULL_ENROLL_UNINSURED_MESSAGE
    End If
    
    If ValidateNullString(aAmIndian) = True Then
        RaiseError VM_NULL_ENROLL_AMINDIAN_NUMBER, _
                    VM_NULL_ENROLL_AMINDIAN_MESSAGE
    End If
    
    If ValidateNullString(aFQHC_RHC) = True Then
        RaiseError VM_NULL_ENROLL_FQHC_RHC_NUMBER, _
                    VM_NULL_ENROLL_FQHC_RHC_MESSAGE
    End If
    
    If ValidateNullString(aVFC) = True Then
        RaiseError VM_NULL_ENROLL_VFC_NUMBER, _
                    VM_NULL_ENROLL_VFC_MESSAGE
    End If
    
    If ValidateNullString(aG317) = True Then
        RaiseError VM_NULL_ENROLL_G317_NUMBER, _
                    VM_NULL_ENROLL_G317_MESSAGE
    End If
    
    If ValidateNullString(aState) = True Then
        RaiseError VM_NULL_ENROLL_STATE_NUMBER, _
                    VM_NULL_ENROLL_STATE_MESSAGE
    End If
    
    ' Validate field lengths
    If Len(LTrim$(RTrim$(aSource))) > 10 Then
        msg = VM_INV_ENROLL_FIELD_LEN_MESSAGE & "Source"
        RaiseError VM_INV_ENROLL_FIELD_LEN_NUMBER, _
                    msg
    End If
    
    If Len(LTrim$(RTrim$(aAll))) > 7 Then
        msg = VM_INV_ENROLL_FIELD_LEN_MESSAGE & "All Kids Total"
        RaiseError VM_INV_ENROLL_FIELD_LEN_NUMBER, _
                    msg
    End If
    
    If Len(LTrim$(RTrim$(aMedicaid))) > 7 Then
        msg = VM_INV_ENROLL_FIELD_LEN_MESSAGE & "Medicaid Total"
        RaiseError VM_INV_ENROLL_FIELD_LEN_NUMBER, _
                    msg
    End If
    
    If Len(LTrim$(RTrim$(aUninsured))) > 7 Then
        msg = VM_INV_ENROLL_FIELD_LEN_MESSAGE & "Uninsured Total"
        RaiseError VM_INV_ENROLL_FIELD_LEN_NUMBER, _
                    msg
    End If
    
    If Len(LTrim$(RTrim$(aAmIndian))) > 7 Then
        msg = VM_INV_ENROLL_FIELD_LEN_MESSAGE & "American Indian Total"
        RaiseError VM_INV_ENROLL_FIELD_LEN_NUMBER, _
                    msg
    End If
    
    If Len(LTrim$(RTrim$(aFQHC_RHC))) > 7 Then
        msg = VM_INV_ENROLL_FIELD_LEN_MESSAGE & "FQHC/RHC Total"
        RaiseError VM_INV_ENROLL_FIELD_LEN_NUMBER, _
                    msg
    End If
    
    If Len(LTrim$(RTrim$(aVFC))) > 7 Then
        msg = VM_INV_ENROLL_FIELD_LEN_MESSAGE & "VFC Total"
        RaiseError VM_INV_ENROLL_FIELD_LEN_NUMBER, _
                    msg
    End If
    
    If Len(LTrim$(RTrim$(aG317))) > 7 Then
        msg = VM_INV_ENROLL_FIELD_LEN_MESSAGE & "G317 Total"
        RaiseError VM_INV_ENROLL_FIELD_LEN_NUMBER, _
                    msg
    End If
    
    If Len(LTrim$(RTrim$(aState))) > 7 Then
        msg = VM_INV_ENROLL_FIELD_LEN_MESSAGE & "State Total"
        RaiseError VM_INV_ENROLL_FIELD_LEN_NUMBER, _
                    msg
    End If
    
    ' Validate Age Group parm
    If IsNumeric(aAgeGroup) = True Then
        age_group = CInt(aAgeGroup)
        If age_group <= 0 Or age_group > 4 Then
            RaiseError VM_ENROLL_INV_AGE_GROUP_NUMBER, _
                       VM_ENROLL_INV_AGE_GROUP_MESSAGE
        End If
    Else
        RaiseError VM_ENROLL_INV_AGE_GROUP_NUMBER, _
                       VM_ENROLL_INV_AGE_GROUP_MESSAGE
    End If
    
    'Validate Source
    source = LTrim$(RTrim$(aSource))
    If source <> "A" And source <> "B" And source <> "C" And source <> "D" And source <> "E" _
       And source <> "F" And source <> "G" And source <> "Z" Then
        RaiseError VM_ENROLL_INV_SOURCE_NUMBER, _
                    VM_ENROLL_INV_SOURCE_MESSAGE
    End If
        
    ' Validate Numeric total fields
    If IsNumeric(aAll) = False Then
        RaiseError VM_ENROLL_INV_ALL_KIDS_NUMBER, _
                   VM_ENROLL_INV_ALL_KIDS_MESSAGE
    Else
        all = CLng(aAll)
    End If
    
    If IsNumeric(aMedicaid) = False Then
        RaiseError VM_ENROLL_INV_MEDICAID_NUMBER, _
                   VM_ENROLL_INV_MEDICAID_MESSAGE
    Else
        medicaid = CLng(aMedicaid)
    End If
    
    If IsNumeric(aUninsured) = False Then
        RaiseError VM_ENROLL_INV_UNINSURED_NUMBER, _
                   VM_ENROLL_INV_UNINSURED_MESSAGE
    Else
        uninsured = CLng(aUninsured)
    End If
    
    If IsNumeric(aAmIndian) = False Then
        RaiseError VM_ENROLL_INV_AMINDIAN_NUMBER, _
                   VM_ENROLL_INV_AMINDIAN_MESSAGE
    Else
        amindian = CLng(aAmIndian)
    End If
    
    If IsNumeric(aFQHC_RHC) = False Then
        RaiseError VM_ENROLL_INV_FQHC_RHC_NUMBER, _
                   VM_ENROLL_INV_FQHC_RHC_MESSAGE
    Else
        fqhc_rhc = CLng(aFQHC_RHC)
    End If
    
    If IsNumeric(aVFC) = False Then
        RaiseError VM_ENROLL_INV_VFC_NUMBER, _
                   VM_ENROLL_INV_VFC_MESSAGE
    Else
        vfc = CLng(aVFC)
    End If
    
    If IsNumeric(aG317) = False Then
        RaiseError VM_ENROLL_INV_G317_NUMBER, _
                   VM_ENROLL_INV_G317_MESSAGE
    Else
        g317 = CLng(aG317)
    End If
    
    If IsNumeric(aState) = False Then
        RaiseError VM_ENROLL_INV_STATE_NUMBER, _
                   VM_ENROLL_INV_STATE_MESSAGE
    Else
        state = CLng(aState)
    End If
    
    If ValidateEnrollmentRecord(aPIN, Connection) = True Then
    ' Existing record, so it's an update
        query = "UPDATE enroll SET ensource= '" & aSource & "', chgdate = {" & chgdate & "}, "
        Select Case age_group
        ' Check age_group to determine which columns to update
            Case 1
                query = query & "allkids1 = " & all & ", medicaid1 = " & medicaid & ", "
                query = query & "uninsured1 = " & uninsured & ", amindian1 = " & amindian & ", "
                query = query & "fqhc_rhc1 = " & fqhc_rhc & ", vfckids1 = " & vfc & ", "
                query = query & "g317kids1 = " & g317 & ", statekids1 = " & state & ", "
            Case 2
                query = query & "allkids2 = " & all & ", medicaid2 = " & medicaid & ", "
                query = query & "uninsured2 = " & uninsured & ", amindian2 = " & amindian & ", "
                query = query & "fqhc_rhc2 = " & fqhc_rhc & ", vfckids2 = " & vfc & ", "
                query = query & "g317kids2 = " & g317 & ", statekids2 = " & state & ", "
            Case 3
                query = query & "allkids3 = " & all & ", medicaid3 = " & medicaid & ", "
                query = query & "uninsured3 = " & uninsured & ", amindian3 = " & amindian & ", "
                query = query & "fqhc_rhc3 = " & fqhc_rhc & ", vfckids3 = " & vfc & ", "
                query = query & "g317kids3 = " & g317 & ", statekids3 = " & state & ", "
            Case 4
                query = query & "allkids4 = " & all & ", medicaid4 = " & medicaid & ", "
                query = query & "uninsured4 = " & uninsured & ", amindian4 = " & amindian & ", "
                query = query & "fqhc_rhc4 = " & fqhc_rhc & ", vfckids4 = " & vfc & ", "
                query = query & "g317kids4 = " & g317 & ", statekids4 = " & state & ", "
        End Select
        query = query & " userid = '" & VACMAN_DLL_USER & "' "
        query = query & "WHERE  ltrim(rtrim(Pin)) = '" & aPIN & "' "
    Else
    ' No match for PIN, so it's an add
        Select Case age_group
        ' Check age_group to determine which columns to add
            Case 1
                query = "INSERT INTO enroll (pin, ensource, chgdate, allkids1, medicaid1, uninsured1, "
                query = query & "amindian1, fqhc_rhc1, vfckids1, g317kids1, statekids1, userid) VALUES"
            Case 2
                query = "INSERT INTO enroll (pin, ensource, chgdate, allkids2, medicaid2, uninsured2, "
                query = query & "amindian2, fqhc_rhc2, vfckids2, g317kids2, statekids2, userid) VALUES"
            Case 3
                query = "INSERT INTO enroll (pin, ensource, chgdate, allkids3, medicaid3, uninsured3, "
                query = query & "amindian3, fqhc_rhc3, vfckids3, g317kids3, statekids3, userid) VALUES"
            Case 4
                query = "INSERT INTO enroll (pin, ensource, chgdate, allkids4, medicaid4, uninsured4, "
                query = query & "amindian4, fqhc_rhc4, vfckids4, g317kids4, statekids4, userid) VALUES"
        End Select
        
        ' Add column values to Query
        query = query & " ( '" & aPIN & "', "
        query = query & "'" & aSource & "', "
        query = query & "{" & chgdate & "}, "
        query = query & all & ", "
        query = query & medicaid & ", "
        query = query & uninsured & ", "
        query = query & amindian & ", "
        query = query & fqhc_rhc & ", "
        query = query & vfc & ", "
        query = query & g317 & ", "
        query = query & state & ", "
        query = query & "'" & VACMAN_DLL_USER & "')"
    End If
                                       
    App.LogEvent query, vbLogEventTypeInformation
    Debug.Print query
    
    'Execute the Query
    recordset.Open query, Connection, adOpenKeyset, adLockReadOnly, adCmdText
    Exit Sub
    
ErrorHandler:
    With recordset
        If .state = adStateOpen Then
            .Close
        End If
    End With
    Set recordset = Nothing
    Debug.Print Err.Number
    Debug.Print Err.Description
    Debug.Print Err.source
    Dim desc As String
    Dim code As Long
    desc = Err.Description
    code = Err.Number
    
    App.LogEvent "Problem: In providerEnrollmentAddUpdate() " & desc, vbLogEventTypeError
    
    Err.Raise code, "VACMAN DLL", desc
    
End Sub

'#########################################################################
' Subroutine Name: providerAdditionalInfoUpdate
'
' Description: Updates a record in the provider table with additional fields.
'
'
' Arguments:
'           aPIN:               The pin of the provider whose profile is being updated
'           aProviderType:      The type of provider (HOSPITAL, PUB HTH, FQHC, etc.)
'           aClassification:
'           aCurrentVFCCert:    Date eligible for VFC program
'           aCohort:
'           aEmpIdNum:          Provider ID Number
'           aImmpact:           Uses ImmPact; Yes/No
'
' Exceptions:
'
' CHANGE HISTORY
' Request Id  Date        Author          Description
' ------------------------------------------------------------------------
' IMMPACT-200 01/25/2007  Mark Fleming    Function Created
'#########################################################################
Public Sub providerAdditionalInfoUpdate(ByVal aPIN As String, _
                                        ByVal aProviderType As String, _
                                        ByVal aClassification As String, _
                                        ByVal aCurrentVFCCert As String, _
                                        ByVal aCohort As String, _
                                        ByVal aEmpIdNum As String, _
                                        ByVal aImmpact As String)
                                        
    On Error GoTo ErrorHandler
    App.LogEvent "Begin: providerAdditionalInfoUpdate()", vbLogEventTypeInformation

    Dim recordset As ADODB.recordset
    Dim query As String
    Dim rowCount As Long
    Dim immpact As String
    Dim vfc As Date
    Dim Class As Integer
    Dim chgdate As Date
    Dim msg As String
            
    chgdate = Date
    
    ' Initialize the recordset to receive query results.
    Set recordset = CreateObject("ADODB.Recordset")
    
     ' Change parameter values to upper case
    aPIN = UCase(aPIN)
    aProviderType = UCase(aProviderType)
    aClassification = UCase(aClassification)
    aCohort = UCase(aCohort)
    aEmpIdNum = UCase(aEmpIdNum)
    aImmpact = UCase(aImmpact)
        
    If ValidateNullString(aPIN) = True Then
        RaiseError VM_NULL_PROVIDER_PIN_NUMBER, _
                    VM_NULL_PROVIDER_PIN_MESSAGE
    End If
    
    If ValidateNullString(aProviderType) = True Then
        RaiseError VM_NULL_PROVIDER_TYPE_NUMBER, _
                    VM_NULL_PROVIDER_TYPE_MESSAGE
    End If
    
    If ValidateNullString(aClassification) = True Then
        RaiseError VM_MISSING_CLASSIFICATION_CODE_NUMBER, _
                    VM_MISSING_CLASSIFICATION_CODE_MESSAGE
    End If
    
    If ValidateNullString(aCurrentVFCCert) = True Then
        RaiseError VM_NULL_PROVIDER_VFC_CERT_DATE_NUMBER, _
                    VM_NULL_PROVIDER_VFC_CERT_DATE_MESSAGE
    End If
    
    If ValidateNullString(aCohort) = True Then
        RaiseError VM_NULL_PROVIDER_COHORT_NUMBER, _
                    VM_NULL_PROVIDER_COHORT_MESSAGE
    End If
    
    If ValidateNullString(aEmpIdNum) = True Then
        RaiseError VM_NULL_PROVIDER_EMP_ID_NUMBER, _
                    VM_NULL_PROVIDER_EMP_ID_MESSAGE
    End If
    
    If ValidateNullString(aImmpact) = True Then
        RaiseError VM_NULL_PROVIDER_IMMPACT_NUMBER, _
                    VM_NULL_PROVIDER_IMMPACT_MESSAGE
    End If
    
    ' Validate field lengths
    If Len(LTrim$(RTrim$(aProviderType))) > 10 Then
        msg = VM_INV_PROVIDER_FIELD_LEN_MESSAGE & "Provider Type"
        RaiseError VM_INV_PROVIDER_FIELD_LEN_NUMBER, _
                    msg
    End If
    
    If Len(LTrim$(RTrim$(aClassification))) > 2 Then
        msg = VM_INV_PROVIDER_FIELD_LEN_MESSAGE & "Classification"
        RaiseError VM_INV_PROVIDER_FIELD_LEN_NUMBER, _
                    msg
    End If
    
    If Len(LTrim$(RTrim$(aCohort))) > 10 Then
        msg = VM_INV_PROVIDER_FIELD_LEN_MESSAGE & "Cohort"
        RaiseError VM_INV_PROVIDER_FIELD_LEN_NUMBER, _
                    msg
    End If
    
    If Len(LTrim$(RTrim$(aEmpIdNum))) > 15 Then
        msg = VM_INV_PROVIDER_FIELD_LEN_MESSAGE & "Employee ID Number"
        RaiseError VM_INV_PROVIDER_FIELD_LEN_NUMBER, _
                    msg
    End If
    
    If IsDate(aCurrentVFCCert) = False Then
        RaiseError VM_INVALID_VFC_CERT_DATE_NUMBER, _
                    VM_INVALID_VFC_CERT_DATE_MESSAGE
    Else
        vfc = DateValue(aCurrentVFCCert)
    End If
     
    If IsNumeric(aClassification) = False Then
        RaiseError VM_INV_PROVIDER_CLASSIFICATION_NUMBER, _
                    VM_INV_PROVIDER_CLASSIFICATION_MESSAGE
    Else
        Class = CInt(aClassification)
    End If
     
    immpact = LTrim$(RTrim$(aImmpact))
    If immpact <> "YES" And immpact <> "NO" Then
        RaiseError VM_INV_PROVIDER_IMMPACT_NUMBER, _
                    VM_INV_PROVIDER_IMMPACT_MESSAGE
    End If
    
    If ValidateProviderPIN(aPIN, True, Connection) = True Then
    ' Existing record, so it's an update
        query = "UPDATE provider SET cat2 = '" & aProviderType & "', " & "chgdate = {" & chgdate & "}, "
        query = query & "sector = " & Class & ", datevfc = {" & vfc & "}, cat4 = '" & aCohort & "', "
        query = query & "alphaid = '" & aEmpIdNum & "', cat1 = '" & immpact & "' "
        query = query & "WHERE  ltrim(rtrim(Pin)) = '" & aPIN & "' "
    Else
    ' No match for PIN, so it's an Error
        RaiseError VM_PROVIDER_PIN_NOT_FOUND_NUMBER, _
                    VM_PROVIDER_PIN_NOT_FOUND_MESSAGE
    End If
                                       
    App.LogEvent query, vbLogEventTypeInformation
    Debug.Print query
    
    'Execute the Query
    recordset.Open query, Connection, adOpenKeyset, adLockReadOnly, adCmdText
    Exit Sub
    
ErrorHandler:
    With recordset
        If .state = adStateOpen Then
            .Close
        End If
    End With
    Set recordset = Nothing
    Debug.Print Err.Number
    Debug.Print Err.Description
    Debug.Print Err.source
    Dim desc As String
    Dim code As Long
    desc = Err.Description
    code = Err.Number
    
    App.LogEvent "Problem: In providerAdditionalInfoUpdate() " & desc, vbLogEventTypeError
    
    Err.Raise code, "VACMAN DLL", desc

End Sub

'#########################################################################
' Subroutine Name: physicianAddUpdate
'
' Description: Updates a record in the physicn table.
'
'
' Arguments:
'           aPIN:               The pin of the provider whose profile is being updated
'           aLastName:          Physician's Last Name
'           aFirstname:         Physician's First Name
'           aMiddleInitial:     Physician's Middle Initial
'           aTitle:             Physican title (such as MD)
'           aSiteMedID:
'           aMedicaidNum:       Physician's Medicaid Number
'           aLicenseNum:        Physician's Medical License Number
'
' Exceptions:
'
' CHANGE HISTORY
' Request Id  Date        Author          Description
' ------------------------------------------------------------------------
' IMMPACT-200 01/25/2007  Mark Fleming    Function Created
'#########################################################################
Public Sub physicianAddUpdate(ByVal aPIN As String, _
                              ByVal aLastName As String, _
                              ByVal aFirstName As String, _
                              ByVal aMiddleInitial As String, _
                              ByVal aTitle As String, _
                              ByVal aSiteMedID As String, _
                              ByVal aMedicaidNum As String, _
                              ByVal aLicenseNum As String)
                       
On Error GoTo ErrorHandler
    App.LogEvent "Begin: physicianAddUpdate()", vbLogEventTypeInformation

    Dim recordset As ADODB.recordset
    Dim query As String
    Dim rowCount As Long
    Dim mid As Boolean
    Dim title As Boolean
    Dim chgdate As Date
    Dim msg As String
    ' New test code
    Dim mednum As Boolean
    Dim licnum As Boolean
    Dim sitemed As Boolean
    
    chgdate = Date
    
     ' Initialize the recordset to receive query results.
    Set recordset = CreateObject("ADODB.Recordset")
    
    ' Change parameter values to upper case
    aPIN = UCase(aPIN)
    aLastName = UCase(aLastName)
    aFirstName = UCase(aFirstName)
    aMiddleInitial = UCase(aMiddleInitial)
    aTitle = UCase(aTitle)
    aSiteMedID = UCase(aSiteMedID)
    aLicenseNum = UCase(aLicenseNum)
        
    If ValidateNullString(aPIN) = True Then
        RaiseError VM_NULL_PROVIDER_PIN_NUMBER, _
                    VM_NULL_PROVIDER_PIN_MESSAGE
    End If
    
    If ValidateNullString(aLastName) = True Then
        RaiseError VM_NULL_PHYS_LAST_NAME_NUMBER, _
                    VM_NULL_PHYS_LAST_NAME_MESSAGE
    End If
    
    If ValidateNullString(aFirstName) = True Then
        RaiseError VM_NULL_PHYS_FIRST_NAME_NUMBER, _
                    VM_NULL_PHYS_FIRST_NAME_MESSAGE
    End If
    
    sitemed = ValidateNullString(aSiteMedID)
    
    mednum = ValidateNullString(aMedicaidNum)
    
    licnum = ValidateNullString(aLicenseNum)
   
    mid = ValidateNullString(aMiddleInitial)
    
    title = ValidateNullString(aTitle)
        
    ' Check field lengths
    If Len(LTrim$(RTrim$(aLastName))) > 20 Then
        msg = VM_INV_PHYS_FIELD_LEN_MESSAGE & "Last Name"
        RaiseError VM_INV_PHYS_FIELD_LEN_NUMBER, _
                    msg
    End If
    
    If Len(LTrim$(RTrim$(aFirstName))) > 15 Then
        msg = VM_INV_PHYS_FIELD_LEN_MESSAGE & "First Name"
        RaiseError VM_INV_PHYS_FIELD_LEN_NUMBER, _
                    msg
    End If
    
    If mid = False Then
        If Len(LTrim$(RTrim$(aMiddleInitial))) > 1 Then
            msg = VM_INV_PHYS_FIELD_LEN_MESSAGE & "Middle Initial"
            RaiseError VM_INV_PHYS_FIELD_LEN_NUMBER, _
                        msg
        End If
    End If
    
    If title = False Then
        If Len(LTrim$(RTrim$(aTitle))) > 9 Then
            msg = VM_INV_PHYS_FIELD_LEN_MESSAGE & "Title"
            RaiseError VM_INV_PHYS_FIELD_LEN_NUMBER, _
                        msg
        End If
    End If
    
    If sitemed = False Then
        If Len(LTrim$(RTrim$(aSiteMedID))) > 12 Then
            msg = VM_INV_PHYS_FIELD_LEN_MESSAGE & "Site Med ID"
            RaiseError VM_INV_PHYS_FIELD_LEN_NUMBER, _
                        msg
        End If
    End If
    
    If mednum = False Then
        If Len(LTrim$(RTrim$(aMedicaidNum))) > 12 Then
            msg = VM_INV_PHYS_FIELD_LEN_MESSAGE & "Medicaid Number"
            RaiseError VM_INV_PHYS_FIELD_LEN_NUMBER, _
                        msg
        End If
    End If
    
    If licnum = False Then
        If Len(LTrim$(RTrim$(aLicenseNum))) > 12 Then
            msg = VM_INV_PHYS_FIELD_LEN_MESSAGE & "License Number"
            RaiseError VM_INV_PHYS_FIELD_LEN_NUMBER, _
                        msg
        End If
    End If
    
    If ValidatePhysicnRecord(aPIN, aLastName, aFirstName, Connection) = True Then
    ' Existing record, so it's an update
        query = "UPDATE physicn SET firstname = '" & aFirstName & "', "
        If mid = False Then query = query & "initial = '" & aMiddleInitial & "', "
        If title = False Then query = query & "title = '" & aTitle & "', "
        If sitemed = False Then query = query & "other1 = '" & aSiteMedID & "', "
        If mednum = False Then query = query & "medicaidno = '" & aMedicaidNum & "', "
        If licnum = False Then query = query & "medlicense = '" & aLicenseNum & "', "
        query = query & "chgdate = {" & chgdate & "} "
        query = query & "WHERE  pin = '" & aPIN & "' AND lastname = '" & aLastName & "' "
    Else
    ' No match for PIN, so it's an add
        query = "INSERT INTO physicn (pin, lastname, firstname, "
        If mid = False Then query = query & "initial, "
        If title = False Then query = query & "title, "
        If sitemed = False Then query = query & "other1, "
        If mednum = False Then query = query & "medicaidno, "
        If licnum = False Then query = query & "medlicense, "
        query = query & "chgdate) "
        query = query & "VALUES ( '" & aPIN & "', '" & aLastName & "', '" & aFirstName & "', "
        If mid = False Then query = query & "'" & aMiddleInitial & "', "
        If title = False Then query = query & "'" & aTitle & "', "
        If sitemed = False Then query = query & "'" & aSiteMedID & "', "
        If mednum = False Then query = query & "'" & aMedicaidNum & "', "
        If licnum = False Then query = query & "'" & aLicenseNum & "', "
        query = query & "{" & chgdate & "} )"
    End If
                                       
    App.LogEvent query, vbLogEventTypeInformation
    Debug.Print query
    
    'Execute the Query
    recordset.Open query, Connection, adOpenKeyset, adLockReadOnly, adCmdText
    
    Exit Sub
    
ErrorHandler:
    With recordset
        If .state = adStateOpen Then
            .Close
        End If
    End With
    Set recordset = Nothing
    Debug.Print Err.Number
    Debug.Print Err.Description
    Debug.Print Err.source
    Dim desc As String
    Dim code As Long
    desc = Err.Description
    code = Err.Number
    
    App.LogEvent "Problem: In physicianAddUpdate() " & desc, vbLogEventTypeError
    
    Err.Raise code, "VACMAN DLL", desc

End Sub

'#########################################################################
' Subroutine Name: provinvAdd
'
' Description: Adds a record in the provhas table.
'
'
' Arguments:
'           aPIN:               The pin of the provider whose inventory is being updated
'           aVacc:              Vaccine Name
'           aInv:               Inventory Count
'           aIdate              Inventory Date
'
' Exceptions:
'
' CHANGE HISTORY
' Request Id  Date        Author          Description
' ------------------------------------------------------------------------
'             04/03/2007  Mark Fleming    Function Created
' IMMPACT-529 06/12/2007  Mark Fleming    Change call to ValidateAgainstVaccRefTable
'                                         to exclude Pin
'             07/05/2007  Matt Martin     Added userid to db record
'#########################################################################
Public Sub provinvAdd(ByVal aPIN As String, _
                      ByVal aVacc As String, _
                      ByVal aInv As String, _
                      ByVal aIdate As String)
                       
On Error GoTo ErrorHandler
    App.LogEvent "Begin: provinvAddUpdate()", vbLogEventTypeInformation

    Dim recordset As ADODB.recordset
    Dim query As String
    Dim rowCount As Long
    Dim chgdate As Date
    Dim msg As String
    Dim doses As Long
    Dim provhasid As Long
    Dim isPINValid As Boolean
    Dim idate As Date
    
    chgdate = Date
    
     ' Initialize the recordset to receive query results.
    Set recordset = CreateObject("ADODB.Recordset")
    
    ' Change parameter value to upper case
    aVacc = UCase(aVacc)
                
    isPINValid = ValidateProviderPIN(aPIN, False, Connection)
           
    If ValidateNullString(aVacc) = True Then
        RaiseError VM_NULL_PROVHAS_VACC_NUMBER, _
                    VM_NULL_PROVHAS_VACC_MESSAGE
    End If
    
    If ValidateNullString(aInv) = True Then
        RaiseError VM_NULL_PROVHAS_INV_NUMBER, _
                    VM_NULL_PROVHAS_INV_MESSAGE
    End If
    
    If ValidateNullString(aIdate) = True Then
        RaiseError VM_NULL_PROVHAS_INV_DATE_NUMBER, _
                    VM_NULL_PROVHAS_INV_DATE_MESSAGE
    End If
    
    ' Validate Fields
    If IsNumeric(aInv) = False Then
        RaiseError VM_INV_PROVHAS_INV_NUMBER, _
                    VM_INV_PROVHAS_INV_MESSAGE
    Else
        doses = CLng(aInv)
    End If
    
    ValidateAgainstpVaccRefTable aVacc, Connection
    
    If IsDate(aIdate) = False Then
        RaiseError VM_INV_PROVHAS_INV_DATE_NUMBER, _
                    VM_INV_PROVHAS_INV_DATE_MESSAGE
    Else
        idate = DateValue(aIdate)
    End If
    
   ' Get next ID for provhasid column
    provhasid = getNextID("provhas")
    
    query = "INSERT INTO provhas (pin, vaccine, doses, chgdate, idate, provhasid, userid) "
    query = query & "VALUES ( '" & aPIN & "', '" & aVacc & "', " & doses & ", "
    query = query & "{" & chgdate & "}, {" & idate & "}, " & provhasid & ", '" & VACMAN_DLL_USER & "') "
                                               
    App.LogEvent query, vbLogEventTypeInformation
    Debug.Print query
    
    'Execute the Query
    recordset.Open query, Connection, adOpenKeyset, adLockReadOnly, adCmdText
    
    Exit Sub
    
ErrorHandler:
    With recordset
        If .state = adStateOpen Then
            .Close
        End If
    End With
    Set recordset = Nothing
    Debug.Print Err.Number
    Debug.Print Err.Description
    Debug.Print Err.source
    Dim desc As String
    Dim code As Long
    desc = Err.Description
    code = Err.Number
    
    App.LogEvent "Problem: In provinvAddUpdate() " & desc, vbLogEventTypeError
    
    Err.Raise code, "VACMAN DLL", desc

End Sub

'#########################################################################
' Subroutine Name: physicianDeleteByPin
'
' Description: Deletes all rows in the physicn table for a given Pin.
'
'
' Arguments:
'           aPIN:               The pin of the provider to delete Physicians for
'
' Exceptions:
'
' CHANGE HISTORY
' Request Id  Date        Author          Description
' ------------------------------------------------------------------------
' IMMPACT-504 06/20/2007  Mark Fleming    Function Created
'#########################################################################
Public Sub physicianDeleteByPin(ByVal aPIN As String) _
                                                     
On Error GoTo ErrorHandler
    App.LogEvent "Begin: physicianDeleteByPin()", vbLogEventTypeInformation

    Dim recordset As ADODB.recordset
    Dim query As String
    
 ' Initialize the recordset to receive query results.
    Set recordset = CreateObject("ADODB.Recordset")
    
    ValidateProviderPIN aPIN, True, Connection
    
    query = "Delete From physicn Where pin == '" & aPIN & "'"
    
    App.LogEvent query, vbLogEventTypeInformation
    Debug.Print query
    
    'Execute the Query
    recordset.Open query, Connection, adOpenKeyset, adLockReadOnly, adCmdText
    
    Exit Sub

ErrorHandler:
    With recordset
        If .state = adStateOpen Then
            .Close
        End If
    End With
    Set recordset = Nothing
    Debug.Print Err.Number
    Debug.Print Err.Description
    Debug.Print Err.source
    Dim desc As String
    Dim code As Long
    desc = Err.Description
    code = Err.Number
    
    App.LogEvent "Problem: In physicianDeleteByPin() " & desc, vbLogEventTypeError
    
    Err.Raise code, "VACMAN DLL", desc

End Sub


Public Sub CheckVaccActive(ByVal aVaccine As String)
    
    If ValidateVaccineActiveStatus(aVaccine, Connection) = False Then
        MsgBox "Vaccine is inactive"
    Else
        MsgBox "Vaccine is Active"
    End If
        
End Sub


